@@ -50,12 +50,14 @@ struct _ValaCCodeCaseStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeCaseStatementPrivate * priv;
 };
+
 struct _ValaCCodeCaseStatementClass {
 	ValaCCodeStatementClass parent_class;
 };
 
+
+ValaCCodeCaseStatement* vala_ccode_case_statement_construct (GType object_type, ValaCCodeExpression* expression);
 ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expression);
-void vala_ccode_case_statement_add_statement (ValaCCodeCaseStatement* self, ValaCCodeStatement* stmt);
 ValaCCodeExpression* vala_ccode_case_statement_get_expression (ValaCCodeCaseStatement* self);
 void vala_ccode_case_statement_set_expression (ValaCCodeCaseStatement* self, ValaCCodeExpression* value);
 GType vala_ccode_case_statement_get_type (void);
