@@ -1,6 +1,6 @@
 /* valaccodeconditionalexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -39,6 +39,7 @@ enum  {
 	VALA_CCODE_CONDITIONAL_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_ccode_conditional_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
+static void vala_ccode_conditional_expression_real_write_inner (ValaCCodeExpression* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_conditional_expression_parent_class = NULL;
 static void vala_ccode_conditional_expression_finalize (ValaCCodeNode* obj);
 
@@ -49,7 +50,7 @@ ValaCCodeConditionalExpression* vala_ccode_conditional_expression_construct (GTy
 	g_return_val_if_fail (cond != NULL, NULL);
 	g_return_val_if_fail (true_expr != NULL, NULL);
 	g_return_val_if_fail (false_expr != NULL, NULL);
-	self = ((ValaCCodeConditionalExpression*) (g_type_create_instance (object_type)));
+	self = (ValaCCodeConditionalExpression*) g_type_create_instance (object_type);
 	vala_ccode_conditional_expression_set_condition (self, cond);
 	vala_ccode_conditional_expression_set_true_expression (self, true_expr);
 	vala_ccode_conditional_expression_set_false_expression (self, false_expr);
@@ -64,14 +65,22 @@ ValaCCodeConditionalExpression* vala_ccode_conditional_expression_new (ValaCCode
 
 static void vala_ccode_conditional_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeConditionalExpression * self;
-	self = ((ValaCCodeConditionalExpression*) (base));
+	self = (ValaCCodeConditionalExpression*) base;
+	g_return_if_fail (writer != NULL);
+	vala_ccode_expression_write_inner (self->priv->_condition, writer);
+	vala_ccode_writer_write_string (writer, " ? ");
+	vala_ccode_expression_write_inner (self->priv->_true_expression, writer);
+	vala_ccode_writer_write_string (writer, " : ");
+	vala_ccode_expression_write_inner (self->priv->_false_expression, writer);
+}
+
+
+static void vala_ccode_conditional_expression_real_write_inner (ValaCCodeExpression* base, ValaCCodeWriter* writer) {
+	ValaCCodeConditionalExpression * self;
+	self = (ValaCCodeConditionalExpression*) base;
 	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_string (writer, "(");
-	vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_condition)), writer);
-	vala_ccode_writer_write_string (writer, " ? ");
-	vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_true_expression)), writer);
-	vala_ccode_writer_write_string (writer, " : ");
-	vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_false_expression)), writer);
+	vala_ccode_node_write ((ValaCCodeNode*) self, writer);
 	vala_ccode_writer_write_string (writer, ")");
 }
 
@@ -88,7 +97,7 @@ void vala_ccode_conditional_expression_set_condition (ValaCCodeConditionalExpres
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL))), _tmp2);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp2);
 }
 
 
@@ -104,7 +113,7 @@ void vala_ccode_conditional_expression_set_true_expression (ValaCCodeConditional
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_true_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_true_expression == NULL ? NULL : (self->priv->_true_expression = (vala_ccode_node_unref (self->priv->_true_expression), NULL))), _tmp2);
+	self->priv->_true_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_true_expression == NULL) ? NULL : (self->priv->_true_expression = (vala_ccode_node_unref (self->priv->_true_expression), NULL)), _tmp2);
 }
 
 
@@ -120,7 +129,7 @@ void vala_ccode_conditional_expression_set_false_expression (ValaCCodeConditiona
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_false_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_false_expression == NULL ? NULL : (self->priv->_false_expression = (vala_ccode_node_unref (self->priv->_false_expression), NULL))), _tmp2);
+	self->priv->_false_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_false_expression == NULL) ? NULL : (self->priv->_false_expression = (vala_ccode_node_unref (self->priv->_false_expression), NULL)), _tmp2);
 }
 
 
@@ -129,6 +138,7 @@ static void vala_ccode_conditional_expression_class_init (ValaCCodeConditionalEx
 	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_conditional_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeConditionalExpressionPrivate));
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_conditional_expression_real_write;
+	VALA_CCODE_EXPRESSION_CLASS (klass)->write_inner = vala_ccode_conditional_expression_real_write_inner;
 }
 
 
@@ -140,9 +150,9 @@ static void vala_ccode_conditional_expression_instance_init (ValaCCodeConditiona
 static void vala_ccode_conditional_expression_finalize (ValaCCodeNode* obj) {
 	ValaCCodeConditionalExpression * self;
 	self = VALA_CCODE_CONDITIONAL_EXPRESSION (obj);
-	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)));
-	(self->priv->_true_expression == NULL ? NULL : (self->priv->_true_expression = (vala_ccode_node_unref (self->priv->_true_expression), NULL)));
-	(self->priv->_false_expression == NULL ? NULL : (self->priv->_false_expression = (vala_ccode_node_unref (self->priv->_false_expression), NULL)));
+	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL));
+	(self->priv->_true_expression == NULL) ? NULL : (self->priv->_true_expression = (vala_ccode_node_unref (self->priv->_true_expression), NULL));
+	(self->priv->_false_expression == NULL) ? NULL : (self->priv->_false_expression = (vala_ccode_node_unref (self->priv->_false_expression), NULL));
 	VALA_CCODE_NODE_CLASS (vala_ccode_conditional_expression_parent_class)->finalize (obj);
 }
 
