@@ -110,7 +110,7 @@ void vala_ccode_node_set_line (ValaCCodeNode* self, ValaCCodeLineDirective* valu
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_line = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_line == NULL ? NULL : (self->priv->_line = (vala_ccode_node_unref (self->priv->_line), NULL))), _tmp2);
+	self->priv->_line = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_line == NULL) ? NULL : (self->priv->_line = (vala_ccode_node_unref (self->priv->_line), NULL)), _tmp2);
 }
 
 
@@ -143,12 +143,13 @@ static gpointer vala_value_ccode_node_peek_pointer (const GValue* value) {
 static gchar* vala_value_ccode_node_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
 	if (collect_values[0].v_pointer) {
 		ValaCCodeNode* object;
-		object = value->data[0].v_pointer;
+		object = collect_values[0].v_pointer;
 		if (object->parent_instance.g_class == NULL) {
 			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
-		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
-			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
 		}
+		value->data[0].v_pointer = vala_ccode_node_ref (object);
 	} else {
 		value->data[0].v_pointer = NULL;
 	}
@@ -160,6 +161,7 @@ static gchar* vala_value_ccode_node_lcopy_value (const GValue* value, guint n_co
 	ValaCCodeNode** object_p;
 	object_p = collect_values[0].v_pointer;
 	if (!object_p) {
+		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
 	}
 	if (!value->data[0].v_pointer) {
 		*object_p = NULL;
@@ -224,7 +226,7 @@ static void vala_ccode_node_instance_init (ValaCCodeNode * self) {
 static void vala_ccode_node_finalize (ValaCCodeNode* obj) {
 	ValaCCodeNode * self;
 	self = VALA_CCODE_NODE (obj);
-	(self->priv->_line == NULL ? NULL : (self->priv->_line = (vala_ccode_node_unref (self->priv->_line), NULL)));
+	(self->priv->_line == NULL) ? NULL : (self->priv->_line = (vala_ccode_node_unref (self->priv->_line), NULL));
 }
 
 
@@ -253,7 +255,7 @@ void vala_ccode_node_unref (gpointer instance) {
 	self = instance;
 	if (g_atomic_int_dec_and_test (&self->ref_count)) {
 		VALA_CCODE_NODE_GET_CLASS (self)->finalize (self);
-		g_type_free_instance (((GTypeInstance *) (self)));
+		g_type_free_instance ((GTypeInstance *) self);
 	}
 }
 
