@@ -52,6 +52,7 @@ struct _GeeArrayListIteratorClass {
 struct _GeeArrayListPrivate {
 	gpointer* _items;
 	gint _items_length1;
+	gint _items_size;
 	gint _size;
 	GEqualFunc _equal_func;
 	gint _stamp;
@@ -111,7 +112,7 @@ static void _vala_array_move (gpointer array, gsize element_size, gint src, gint
 
 GeeArrayList* gee_array_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func) {
 	GeeArrayList* self;
-	self = ((GeeArrayList*) (g_type_create_instance (object_type)));
+	self = (GeeArrayList*) g_type_create_instance (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -127,28 +128,28 @@ GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDest
 
 static GType gee_array_list_real_get_element_type (GeeIterable* base) {
 	GeeArrayList * self;
-	self = ((GeeArrayList*) (base));
+	self = (GeeArrayList*) base;
 	return self->priv->g_type;
 }
 
 
 static GeeIterator* gee_array_list_real_iterator (GeeIterable* base) {
 	GeeArrayList * self;
-	self = ((GeeArrayList*) (base));
-	return ((GeeIterator*) (gee_array_list_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func, self)));
+	self = (GeeArrayList*) base;
+	return (GeeIterator*) gee_array_list_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func, self);
 }
 
 
 static gboolean gee_array_list_real_contains (GeeCollection* base, gconstpointer item) {
 	GeeArrayList * self;
-	self = ((GeeArrayList*) (base));
-	return (gee_list_index_of (((GeeList*) (self)), item) != -1);
+	self = (GeeArrayList*) base;
+	return gee_list_index_of ((GeeList*) self, item) != (-1);
 }
 
 
 static gint gee_array_list_real_index_of (GeeList* base, gconstpointer item) {
 	GeeArrayList * self;
-	self = ((GeeArrayList*) (base));
+	self = (GeeArrayList*) base;
 	{
 		gint index;
 		index = 0;
@@ -164,39 +165,53 @@ static gint gee_array_list_real_index_of (GeeList* base, gconstpointer item) {
 
 static gpointer gee_array_list_real_get (GeeList* base, gint index) {
 	GeeArrayList * self;
-	gconstpointer _tmp0;
-	self = ((GeeArrayList*) (base));
-	g_assert (index >= 0 && index < self->priv->_size);
-	_tmp0 = NULL;
-	return (_tmp0 = self->priv->_items[index], (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0)))));
+	gboolean _tmp0;
+	gconstpointer _tmp1;
+	self = (GeeArrayList*) base;
+	_tmp0 = FALSE;
+	if (index >= 0) {
+		_tmp0 = index < self->priv->_size;
+	} else {
+		_tmp0 = FALSE;
+	}
+	g_assert (_tmp0);
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->_items[index], ((_tmp1 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1) : self->priv->g_dup_func ((gpointer) _tmp1));
 }
 
 
 static void gee_array_list_real_set (GeeList* base, gint index, gconstpointer item) {
 	GeeArrayList * self;
-	gpointer _tmp1;
-	gconstpointer _tmp0;
-	self = ((GeeArrayList*) (base));
-	g_assert (index >= 0 && index < self->priv->_size);
+	gboolean _tmp0;
+	gpointer _tmp2;
+	gconstpointer _tmp1;
+	self = (GeeArrayList*) base;
+	_tmp0 = FALSE;
+	if (index >= 0) {
+		_tmp0 = index < self->priv->_size;
+	} else {
+		_tmp0 = FALSE;
+	}
+	g_assert (_tmp0);
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0))))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
+	self->priv->_items[index] = (_tmp2 = (_tmp1 = item, ((_tmp1 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1) : self->priv->g_dup_func ((gpointer) _tmp1)), ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp2);
 }
 
 
 static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item) {
 	GeeArrayList * self;
-	gint _tmp2;
-	gpointer _tmp1;
+	gpointer _tmp2;
+	gpointer *_tmp1;
 	gconstpointer _tmp0;
-	self = ((GeeArrayList*) (base));
+	self = (GeeArrayList*) base;
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
-	_tmp1 = NULL;
+	_tmp2 = NULL;
 	_tmp0 = NULL;
-	_tmp2 = self->priv->_size++;
-	self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0))))), (self->priv->_items[_tmp2] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL))), _tmp1);
+	_tmp1 = &self->priv->_items[self->priv->_size++];
+	(*_tmp1) = (_tmp2 = (_tmp0 = item, ((_tmp0 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp0) : self->priv->g_dup_func ((gpointer) _tmp0)), (((*_tmp1) == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : ((*_tmp1) = (self->priv->g_destroy_func ((*_tmp1)), NULL)), _tmp2);
 	self->priv->_stamp++;
 	return TRUE;
 }
@@ -204,30 +219,37 @@ static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item
 
 static void gee_array_list_real_insert (GeeList* base, gint index, gconstpointer item) {
 	GeeArrayList * self;
-	gpointer _tmp1;
-	gconstpointer _tmp0;
-	self = ((GeeArrayList*) (base));
-	g_assert (index >= 0 && index <= self->priv->_size);
+	gboolean _tmp0;
+	gpointer _tmp2;
+	gconstpointer _tmp1;
+	self = (GeeArrayList*) base;
+	_tmp0 = FALSE;
+	if (index >= 0) {
+		_tmp0 = index <= self->priv->_size;
+	} else {
+		_tmp0 = FALSE;
+	}
+	g_assert (_tmp0);
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
 	gee_array_list_shift (self, index, 1);
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0))))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
+	self->priv->_items[index] = (_tmp2 = (_tmp1 = item, ((_tmp1 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1) : self->priv->g_dup_func ((gpointer) _tmp1)), ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp2);
 	self->priv->_stamp++;
 }
 
 
 static gboolean gee_array_list_real_remove (GeeCollection* base, gconstpointer item) {
 	GeeArrayList * self;
-	self = ((GeeArrayList*) (base));
+	self = (GeeArrayList*) base;
 	{
 		gint index;
 		index = 0;
 		for (; index < self->priv->_size; index++) {
 			if (self->priv->_equal_func (self->priv->_items[index], item)) {
-				gee_list_remove_at (((GeeList*) (self)), index);
+				gee_list_remove_at ((GeeList*) self, index);
 				return TRUE;
 			}
 		}
@@ -238,11 +260,18 @@ static gboolean gee_array_list_real_remove (GeeCollection* base, gconstpointer i
 
 static void gee_array_list_real_remove_at (GeeList* base, gint index) {
 	GeeArrayList * self;
-	gpointer _tmp0;
-	self = ((GeeArrayList*) (base));
-	g_assert (index >= 0 && index < self->priv->_size);
-	_tmp0 = NULL;
-	self->priv->_items[index] = (_tmp0 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp0);
+	gboolean _tmp0;
+	gpointer _tmp1;
+	self = (GeeArrayList*) base;
+	_tmp0 = FALSE;
+	if (index >= 0) {
+		_tmp0 = index < self->priv->_size;
+	} else {
+		_tmp0 = FALSE;
+	}
+	g_assert (_tmp0);
+	_tmp1 = NULL;
+	self->priv->_items[index] = (_tmp1 = NULL, ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp1);
 	gee_array_list_shift (self, index + 1, -1);
 	self->priv->_stamp++;
 }
@@ -250,14 +279,14 @@ static void gee_array_list_real_remove_at (GeeList* base, gint index) {
 
 static void gee_array_list_real_clear (GeeCollection* base) {
 	GeeArrayList * self;
-	self = ((GeeArrayList*) (base));
+	self = (GeeArrayList*) base;
 	{
 		gint index;
 		index = 0;
 		for (; index < self->priv->_size; index++) {
 			gpointer _tmp0;
 			_tmp0 = NULL;
-			self->priv->_items[index] = (_tmp0 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp0);
+			self->priv->_items[index] = (_tmp0 = NULL, ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp0);
 		}
 	}
 	self->priv->_size = 0;
@@ -266,10 +295,24 @@ static void gee_array_list_real_clear (GeeCollection* base) {
 
 
 static void gee_array_list_shift (GeeArrayList* self, gint start, gint delta) {
+	gboolean _tmp0;
+	gboolean _tmp1;
 	g_return_if_fail (self != NULL);
-	g_assert (start >= 0 && start <= self->priv->_size && start >= -delta);
+	_tmp0 = FALSE;
+	_tmp1 = FALSE;
+	if (start >= 0) {
+		_tmp1 = start <= self->priv->_size;
+	} else {
+		_tmp1 = FALSE;
+	}
+	if (_tmp1) {
+		_tmp0 = start >= (-delta);
+	} else {
+		_tmp0 = FALSE;
+	}
+	g_assert (_tmp0);
 	_vala_array_move (self->priv->_items, sizeof (gpointer), start, start + delta, self->priv->_size - start);
-	self->priv->_size = self->priv->_size + (delta);
+	self->priv->_size = self->priv->_size + delta;
 }
 
 
@@ -279,8 +322,15 @@ static void gee_array_list_grow_if_needed (GeeArrayList* self, gint new_count) {
 	g_assert (new_count >= 0);
 	minimum_size = self->priv->_size + new_count;
 	if (minimum_size > self->priv->_items_length1) {
+		gint _tmp0;
+		_tmp0 = 0;
+		if (new_count > self->priv->_items_length1) {
+			_tmp0 = minimum_size;
+		} else {
+			_tmp0 = 2 * self->priv->_items_length1;
+		}
 		/* double the capacity unless we add even more items at this time*/
-		gee_array_list_set_capacity (self, (new_count > self->priv->_items_length1 ? minimum_size : 2 * self->priv->_items_length1));
+		gee_array_list_set_capacity (self, _tmp0);
 	}
 }
 
@@ -291,14 +341,14 @@ static void gee_array_list_set_capacity (GeeArrayList* self, gint value) {
 	g_assert (value >= self->priv->_size);
 	_tmp0 = value;
 	self->priv->_items = g_renew (gpointer, self->priv->_items, value);
-	(_tmp0 > self->priv->_items_length1 ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (_tmp0 - self->priv->_items_length1)) : NULL);
+	(_tmp0 > self->priv->_items_length1) ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (_tmp0 - self->priv->_items_length1)) : NULL;
 	self->priv->_items_length1 = _tmp0;
 }
 
 
 static gint gee_array_list_real_get_size (GeeCollection* base) {
 	GeeArrayList* self;
-	self = ((GeeArrayList*) (base));
+	self = (GeeArrayList*) base;
 	return self->priv->_size;
 }
 
@@ -312,7 +362,7 @@ void gee_array_list_set_equal_func (GeeArrayList* self, GEqualFunc value) {
 static GeeArrayListIterator* gee_array_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list) {
 	GeeArrayListIterator* self;
 	g_return_val_if_fail (list != NULL, NULL);
-	self = ((GeeArrayListIterator*) (g_type_create_instance (object_type)));
+	self = (GeeArrayListIterator*) g_type_create_instance (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -328,23 +378,30 @@ static GeeArrayListIterator* gee_array_list_iterator_new (GType g_type, GBoxedCo
 
 static gboolean gee_array_list_iterator_real_next (GeeIterator* base) {
 	GeeArrayListIterator * self;
-	self = ((GeeArrayListIterator*) (base));
+	self = (GeeArrayListIterator*) base;
 	g_assert (self->_stamp == self->priv->_list->priv->_stamp);
 	if (self->priv->_index < self->priv->_list->priv->_size) {
 		self->priv->_index++;
 	}
-	return (self->priv->_index < self->priv->_list->priv->_size);
+	return self->priv->_index < self->priv->_list->priv->_size;
 }
 
 
 static gpointer gee_array_list_iterator_real_get (GeeIterator* base) {
 	GeeArrayListIterator * self;
-	self = ((GeeArrayListIterator*) (base));
+	gboolean _tmp0;
+	self = (GeeArrayListIterator*) base;
 	g_assert (self->_stamp == self->priv->_list->priv->_stamp);
-	if (self->priv->_index < 0 || self->priv->_index >= self->priv->_list->priv->_size) {
+	_tmp0 = FALSE;
+	if (self->priv->_index < 0) {
+		_tmp0 = TRUE;
+	} else {
+		_tmp0 = self->priv->_index >= self->priv->_list->priv->_size;
+	}
+	if (_tmp0) {
 		return NULL;
 	}
-	return gee_list_get (((GeeList*) (self->priv->_list)), self->priv->_index);
+	return gee_list_get ((GeeList*) self->priv->_list, self->priv->_index);
 }
 
 
@@ -354,7 +411,7 @@ static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArr
 	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : gee_collection_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL))), _tmp1);
+	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : gee_collection_object_ref (_tmp0)), (self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL)), _tmp1);
 	self->_stamp = self->priv->_list->priv->_stamp;
 }
 
@@ -383,7 +440,7 @@ static void gee_array_list_iterator_instance_init (GeeArrayListIterator * self)
 static void gee_array_list_iterator_finalize (GeeCollectionObject* obj) {
 	GeeArrayListIterator * self;
 	self = GEE_ARRAY_LIST_ITERATOR (obj);
-	(self->priv->_list == NULL ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL)));
+	(self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL));
 	GEE_COLLECTION_OBJECT_CLASS (gee_array_list_iterator_parent_class)->finalize (obj);
 }
 
@@ -445,7 +502,7 @@ static void gee_array_list_instance_init (GeeArrayList * self) {
 static void gee_array_list_finalize (GeeCollectionObject* obj) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (obj);
-	self->priv->_items = (_vala_array_free (self->priv->_items, self->priv->_items_length1, ((GDestroyNotify) (self->priv->g_destroy_func))), NULL);
+	self->priv->_items = (_vala_array_free (self->priv->_items, self->priv->_items_length1, (GDestroyNotify) self->priv->g_destroy_func), NULL);
 	GEE_COLLECTION_OBJECT_CLASS (gee_array_list_parent_class)->finalize (obj);
 }
 
@@ -467,16 +524,12 @@ GType gee_array_list_get_type (void) {
 
 
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
-	if (array != NULL && destroy_func != NULL) {
+	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
-		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) (array))[i] != NULL)
-			destroy_func (((gpointer*) (array))[i]);
-		}
-		else
-		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) (array))[i]);
+			if (((gpointer*) array)[i] != NULL) {
+				destroy_func (((gpointer*) array)[i]);
+			}
 		}
 	}
 	g_free (array);
@@ -484,11 +537,11 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 
 
 static void _vala_array_move (gpointer array, gsize element_size, gint src, gint dest, gint length) {
-	g_memmove (((char*) (array)) + dest * element_size, ((char*) (array)) + src * element_size, length * element_size);
+	g_memmove (((char*) array) + (dest * element_size), ((char*) array) + (src * element_size), length * element_size);
 	if (src < dest) {
-		memset (((char*) (array)) + src * element_size, 0, (dest - src) * element_size);
+		memset (((char*) array) + (src * element_size), 0, (dest - src) * element_size);
 	} else {
-		memset (((char*) (array)) + (dest + length) * element_size, 0, (src - dest) * element_size);
+		memset (((char*) array) + ((dest + length) * element_size), 0, (src - dest) * element_size);
 	}
 }
 
