@@ -1,6 +1,6 @@
 /* readonlyset.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collectionobject.h>
 #include <gee/iterable.h>
 #include <gee/collection.h>
 #include <gee/set.h>
@@ -48,17 +49,21 @@ typedef struct _GeeReadOnlySetPrivate GeeReadOnlySetPrivate;
  * Represents a read-only collection of items without duplicates.
  */
 struct _GeeReadOnlySet {
-	GObject parent_instance;
+	GeeCollectionObject parent_instance;
 	GeeReadOnlySetPrivate * priv;
 };
+
 struct _GeeReadOnlySetClass {
-	GObjectClass parent_class;
+	GeeCollectionObjectClass parent_class;
 };
 
+
+GeeReadOnlySet* gee_read_only_set_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set);
 GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set);
 void gee_read_only_set_set_set (GeeReadOnlySet* self, GeeSet* value);
 GType gee_read_only_set_get_type (void);
 
+
 G_END_DECLS
 
 #endif
