@@ -221,11 +221,11 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_simple_assignment
 	gboolean unref_old;
 	gboolean array;
 	gboolean instance_delegate;
-	gboolean _tmp5;
-	gboolean _tmp6;
+	gboolean _tmp8;
+	gboolean _tmp9;
 	ValaCCodeAssignmentOperator cop;
 	ValaCCodeExpression* codenode;
-	ValaCCodeExpression* _tmp32;
+	ValaCCodeExpression* _tmp35;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (assignment != NULL, NULL);
 	_tmp0 = NULL;
@@ -257,140 +257,158 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_simple_assignment
 			ValaDelegateType* delegate_type;
 			_tmp4 = NULL;
 			delegate_type = (_tmp4 = VALA_DELEGATE_TYPE (vala_expression_get_value_type (vala_assignment_get_left (assignment))), (_tmp4 == NULL) ? NULL : vala_code_node_ref (_tmp4));
-			instance_delegate = vala_delegate_get_has_target (vala_delegate_type_get_delegate_symbol (delegate_type));
+			if (vala_delegate_get_has_target (vala_delegate_type_get_delegate_symbol (delegate_type))) {
+				ValaField* _tmp6;
+				ValaSymbol* _tmp5;
+				ValaField* delegate_field;
+				gboolean _tmp7;
+				_tmp6 = NULL;
+				_tmp5 = NULL;
+				delegate_field = (_tmp6 = (_tmp5 = vala_expression_get_symbol_reference (vala_assignment_get_left (assignment)), VALA_IS_FIELD (_tmp5) ? ((ValaField*) _tmp5) : NULL), (_tmp6 == NULL) ? NULL : vala_code_node_ref (_tmp6));
+				_tmp7 = FALSE;
+				if (delegate_field == NULL) {
+					_tmp7 = TRUE;
+				} else {
+					_tmp7 = !vala_field_get_no_delegate_target (delegate_field);
+				}
+				if (_tmp7) {
+					instance_delegate = TRUE;
+				}
+				(delegate_field == NULL) ? NULL : (delegate_field = (vala_code_node_unref (delegate_field), NULL));
+			}
 			(delegate_type == NULL) ? NULL : (delegate_type = (vala_code_node_unref (delegate_type), NULL));
 		}
 	}
-	_tmp5 = FALSE;
-	_tmp6 = FALSE;
+	_tmp8 = FALSE;
+	_tmp9 = FALSE;
 	if (unref_old) {
-		_tmp6 = TRUE;
+		_tmp9 = TRUE;
 	} else {
-		_tmp6 = array;
+		_tmp9 = array;
 	}
-	if (_tmp6) {
-		_tmp5 = TRUE;
+	if (_tmp9) {
+		_tmp8 = TRUE;
 	} else {
-		_tmp5 = instance_delegate;
+		_tmp8 = instance_delegate;
 	}
-	if (_tmp5) {
+	if (_tmp8) {
 		ValaCCodeCommaExpression* ccomma;
 		ValaLocalVariable* temp_decl;
-		ValaCCodeAssignment* _tmp17;
-		ValaCCodeExpression* _tmp16;
-		ValaCCodeExpression* _tmp27;
-		ValaCCodeExpression* _tmp29;
-		ValaCCodeExpression* _tmp28;
+		ValaCCodeAssignment* _tmp20;
+		ValaCCodeExpression* _tmp19;
+		ValaCCodeExpression* _tmp30;
+		ValaCCodeExpression* _tmp32;
+		ValaCCodeExpression* _tmp31;
 		ccomma = vala_ccode_comma_expression_new ();
 		if (!vala_ccode_base_module_is_pure_ccode_expression ((ValaCCodeBaseModule*) self, lhs)) {
-			ValaCCodeCommaExpression* _tmp7;
+			ValaCCodeCommaExpression* _tmp10;
 			ValaDataType* lhs_value_type;
 			char* lhs_temp_name;
-			char* _tmp8;
-			ValaLocalVariable* _tmp9;
+			char* _tmp11;
+			ValaLocalVariable* _tmp12;
 			ValaLocalVariable* lhs_temp;
-			ValaCCodeAssignment* _tmp12;
-			ValaCCodeUnaryExpression* _tmp11;
-			ValaCCodeExpression* _tmp10;
-			ValaCCodeExpression* _tmp15;
+			ValaCCodeAssignment* _tmp15;
 			ValaCCodeUnaryExpression* _tmp14;
 			ValaCCodeExpression* _tmp13;
+			ValaCCodeExpression* _tmp18;
+			ValaCCodeUnaryExpression* _tmp17;
+			ValaCCodeExpression* _tmp16;
 			/* Assign lhs to temp var to avoid repeating side effect */
-			_tmp7 = NULL;
-			outer_ccomma = (_tmp7 = vala_ccode_comma_expression_new (), (outer_ccomma == NULL) ? NULL : (outer_ccomma = (vala_ccode_node_unref (outer_ccomma), NULL)), _tmp7);
+			_tmp10 = NULL;
+			outer_ccomma = (_tmp10 = vala_ccode_comma_expression_new (), (outer_ccomma == NULL) ? NULL : (outer_ccomma = (vala_ccode_node_unref (outer_ccomma), NULL)), _tmp10);
 			lhs_value_type = vala_data_type_copy (vala_expression_get_value_type (vala_assignment_get_left (assignment)));
 			lhs_temp_name = g_strdup_printf ("_tmp%d", ((ValaCCodeBaseModule*) self)->next_temp_var_id++);
-			_tmp8 = NULL;
-			_tmp9 = NULL;
-			lhs_temp = (_tmp9 = vala_local_variable_new (lhs_value_type, _tmp8 = g_strconcat ("*", lhs_temp_name, NULL), NULL, NULL), _tmp8 = (g_free (_tmp8), NULL), _tmp9);
-			gee_list_insert ((GeeList*) ((ValaCCodeBaseModule*) self)->temp_vars, 0, lhs_temp);
-			_tmp12 = NULL;
 			_tmp11 = NULL;
-			_tmp10 = NULL;
-			vala_ccode_comma_expression_append_expression (outer_ccomma, (ValaCCodeExpression*) (_tmp12 = vala_ccode_assignment_new (_tmp10 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, lhs_temp_name), (ValaCCodeExpression*) (_tmp11 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, lhs)), VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-			(_tmp12 == NULL) ? NULL : (_tmp12 = (vala_ccode_node_unref (_tmp12), NULL));
-			(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL));
-			(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL));
+			_tmp12 = NULL;
+			lhs_temp = (_tmp12 = vala_local_variable_new (lhs_value_type, _tmp11 = g_strconcat ("*", lhs_temp_name, NULL), NULL, NULL), _tmp11 = (g_free (_tmp11), NULL), _tmp12);
+			gee_list_insert ((GeeList*) ((ValaCCodeBaseModule*) self)->temp_vars, 0, lhs_temp);
 			_tmp15 = NULL;
 			_tmp14 = NULL;
 			_tmp13 = NULL;
-			lhs = (_tmp15 = (ValaCCodeExpression*) vala_ccode_parenthesized_expression_new ((ValaCCodeExpression*) (_tmp14 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION, _tmp13 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, lhs_temp_name)))), (lhs == NULL) ? NULL : (lhs = (vala_ccode_node_unref (lhs), NULL)), _tmp15);
+			vala_ccode_comma_expression_append_expression (outer_ccomma, (ValaCCodeExpression*) (_tmp15 = vala_ccode_assignment_new (_tmp13 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, lhs_temp_name), (ValaCCodeExpression*) (_tmp14 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, lhs)), VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+			(_tmp15 == NULL) ? NULL : (_tmp15 = (vala_ccode_node_unref (_tmp15), NULL));
 			(_tmp14 == NULL) ? NULL : (_tmp14 = (vala_ccode_node_unref (_tmp14), NULL));
 			(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_ccode_node_unref (_tmp13), NULL));
+			_tmp18 = NULL;
+			_tmp17 = NULL;
+			_tmp16 = NULL;
+			lhs = (_tmp18 = (ValaCCodeExpression*) vala_ccode_parenthesized_expression_new ((ValaCCodeExpression*) (_tmp17 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION, _tmp16 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, lhs_temp_name)))), (lhs == NULL) ? NULL : (lhs = (vala_ccode_node_unref (lhs), NULL)), _tmp18);
+			(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL));
+			(_tmp16 == NULL) ? NULL : (_tmp16 = (vala_ccode_node_unref (_tmp16), NULL));
 			(lhs_value_type == NULL) ? NULL : (lhs_value_type = (vala_code_node_unref (lhs_value_type), NULL));
 			lhs_temp_name = (g_free (lhs_temp_name), NULL);
 			(lhs_temp == NULL) ? NULL : (lhs_temp = (vala_code_node_unref (lhs_temp), NULL));
 		}
 		temp_decl = vala_ccode_base_module_get_temp_variable ((ValaCCodeBaseModule*) self, vala_expression_get_value_type (vala_assignment_get_left (assignment)), TRUE, NULL);
 		gee_list_insert ((GeeList*) ((ValaCCodeBaseModule*) self)->temp_vars, 0, temp_decl);
-		_tmp17 = NULL;
-		_tmp16 = NULL;
-		vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp17 = vala_ccode_assignment_new (_tmp16 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) temp_decl)), rhs, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-		(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL));
-		(_tmp16 == NULL) ? NULL : (_tmp16 = (vala_ccode_node_unref (_tmp16), NULL));
+		_tmp20 = NULL;
+		_tmp19 = NULL;
+		vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp20 = vala_ccode_assignment_new (_tmp19 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) temp_decl)), rhs, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+		(_tmp20 == NULL) ? NULL : (_tmp20 = (vala_ccode_node_unref (_tmp20), NULL));
+		(_tmp19 == NULL) ? NULL : (_tmp19 = (vala_ccode_node_unref (_tmp19), NULL));
 		if (unref_old) {
-			ValaCCodeExpression* _tmp18;
+			ValaCCodeExpression* _tmp21;
 			/* unref old value */
-			_tmp18 = NULL;
-			vala_ccode_comma_expression_append_expression (ccomma, _tmp18 = vala_ccode_base_module_get_unref_expression ((ValaCCodeBaseModule*) self, lhs, vala_expression_get_value_type (vala_assignment_get_left (assignment)), vala_assignment_get_left (assignment)));
-			(_tmp18 == NULL) ? NULL : (_tmp18 = (vala_ccode_node_unref (_tmp18), NULL));
+			_tmp21 = NULL;
+			vala_ccode_comma_expression_append_expression (ccomma, _tmp21 = vala_ccode_base_module_get_unref_expression ((ValaCCodeBaseModule*) self, lhs, vala_expression_get_value_type (vala_assignment_get_left (assignment)), vala_assignment_get_left (assignment)));
+			(_tmp21 == NULL) ? NULL : (_tmp21 = (vala_ccode_node_unref (_tmp21), NULL));
 		}
 		if (array) {
-			ValaArrayType* _tmp19;
+			ValaArrayType* _tmp22;
 			ValaArrayType* array_type;
-			_tmp19 = NULL;
-			array_type = (_tmp19 = VALA_ARRAY_TYPE (vala_expression_get_value_type (vala_assignment_get_left (assignment))), (_tmp19 == NULL) ? NULL : vala_code_node_ref (_tmp19));
+			_tmp22 = NULL;
+			array_type = (_tmp22 = VALA_ARRAY_TYPE (vala_expression_get_value_type (vala_assignment_get_left (assignment))), (_tmp22 == NULL) ? NULL : vala_code_node_ref (_tmp22));
 			{
 				gint dim;
 				dim = 1;
 				for (; dim <= vala_array_type_get_rank (array_type); dim++) {
 					ValaCCodeExpression* lhs_array_len;
 					ValaCCodeExpression* rhs_array_len;
-					ValaCCodeAssignment* _tmp20;
+					ValaCCodeAssignment* _tmp23;
 					lhs_array_len = vala_ccode_module_get_array_length_cexpression (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_assignment_get_left (assignment), dim);
 					rhs_array_len = vala_ccode_module_get_array_length_cexpression (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_assignment_get_right (assignment), dim);
-					_tmp20 = NULL;
-					vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp20 = vala_ccode_assignment_new (lhs_array_len, rhs_array_len, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-					(_tmp20 == NULL) ? NULL : (_tmp20 = (vala_ccode_node_unref (_tmp20), NULL));
+					_tmp23 = NULL;
+					vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp23 = vala_ccode_assignment_new (lhs_array_len, rhs_array_len, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+					(_tmp23 == NULL) ? NULL : (_tmp23 = (vala_ccode_node_unref (_tmp23), NULL));
 					(lhs_array_len == NULL) ? NULL : (lhs_array_len = (vala_ccode_node_unref (lhs_array_len), NULL));
 					(rhs_array_len == NULL) ? NULL : (rhs_array_len = (vala_ccode_node_unref (rhs_array_len), NULL));
 				}
 			}
 			if (vala_array_type_get_rank (array_type) == 1) {
-				ValaSymbol* _tmp21;
+				ValaSymbol* _tmp24;
 				ValaSymbol* array_var;
-				gboolean _tmp22;
-				gboolean _tmp23;
-				_tmp21 = NULL;
-				array_var = (_tmp21 = vala_expression_get_symbol_reference (vala_assignment_get_left (assignment)), (_tmp21 == NULL) ? NULL : vala_code_node_ref (_tmp21));
-				_tmp22 = FALSE;
-				_tmp23 = FALSE;
+				gboolean _tmp25;
+				gboolean _tmp26;
+				_tmp24 = NULL;
+				array_var = (_tmp24 = vala_expression_get_symbol_reference (vala_assignment_get_left (assignment)), (_tmp24 == NULL) ? NULL : vala_code_node_ref (_tmp24));
+				_tmp25 = FALSE;
+				_tmp26 = FALSE;
 				if (array_var != NULL) {
-					_tmp23 = vala_symbol_is_internal_symbol (array_var);
+					_tmp26 = vala_symbol_is_internal_symbol (array_var);
 				} else {
-					_tmp23 = FALSE;
+					_tmp26 = FALSE;
 				}
-				if (_tmp23) {
-					gboolean _tmp24;
-					_tmp24 = FALSE;
+				if (_tmp26) {
+					gboolean _tmp27;
+					_tmp27 = FALSE;
 					if (VALA_IS_LOCAL_VARIABLE (array_var)) {
-						_tmp24 = TRUE;
+						_tmp27 = TRUE;
 					} else {
-						_tmp24 = VALA_IS_FIELD (array_var);
+						_tmp27 = VALA_IS_FIELD (array_var);
 					}
-					_tmp22 = _tmp24;
+					_tmp25 = _tmp27;
 				} else {
-					_tmp22 = FALSE;
+					_tmp25 = FALSE;
 				}
-				if (_tmp22) {
+				if (_tmp25) {
 					ValaCCodeExpression* lhs_array_size;
 					ValaCCodeExpression* rhs_array_len;
-					ValaCCodeAssignment* _tmp25;
+					ValaCCodeAssignment* _tmp28;
 					lhs_array_size = vala_ccode_module_get_array_size_cexpression (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_assignment_get_left (assignment));
 					rhs_array_len = vala_ccode_module_get_array_length_cexpression (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_assignment_get_left (assignment), 1);
-					_tmp25 = NULL;
-					vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp25 = vala_ccode_assignment_new (lhs_array_size, rhs_array_len, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-					(_tmp25 == NULL) ? NULL : (_tmp25 = (vala_ccode_node_unref (_tmp25), NULL));
+					_tmp28 = NULL;
+					vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp28 = vala_ccode_assignment_new (lhs_array_size, rhs_array_len, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+					(_tmp28 == NULL) ? NULL : (_tmp28 = (vala_ccode_node_unref (_tmp28), NULL));
 					(lhs_array_size == NULL) ? NULL : (lhs_array_size = (vala_ccode_node_unref (lhs_array_size), NULL));
 					(rhs_array_len == NULL) ? NULL : (rhs_array_len = (vala_ccode_node_unref (rhs_array_len), NULL));
 				}
@@ -401,22 +419,22 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_simple_assignment
 			if (instance_delegate) {
 				ValaCCodeExpression* lhs_delegate_target;
 				ValaCCodeExpression* rhs_delegate_target;
-				ValaCCodeAssignment* _tmp26;
+				ValaCCodeAssignment* _tmp29;
 				lhs_delegate_target = vala_ccode_base_module_get_delegate_target_cexpression ((ValaCCodeBaseModule*) self, vala_assignment_get_left (assignment));
 				rhs_delegate_target = vala_ccode_base_module_get_delegate_target_cexpression ((ValaCCodeBaseModule*) self, vala_assignment_get_right (assignment));
-				_tmp26 = NULL;
-				vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp26 = vala_ccode_assignment_new (lhs_delegate_target, rhs_delegate_target, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-				(_tmp26 == NULL) ? NULL : (_tmp26 = (vala_ccode_node_unref (_tmp26), NULL));
+				_tmp29 = NULL;
+				vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp29 = vala_ccode_assignment_new (lhs_delegate_target, rhs_delegate_target, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+				(_tmp29 == NULL) ? NULL : (_tmp29 = (vala_ccode_node_unref (_tmp29), NULL));
 				(lhs_delegate_target == NULL) ? NULL : (lhs_delegate_target = (vala_ccode_node_unref (lhs_delegate_target), NULL));
 				(rhs_delegate_target == NULL) ? NULL : (rhs_delegate_target = (vala_ccode_node_unref (rhs_delegate_target), NULL));
 			}
 		}
-		_tmp27 = NULL;
-		vala_ccode_comma_expression_append_expression (ccomma, _tmp27 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) temp_decl)));
-		(_tmp27 == NULL) ? NULL : (_tmp27 = (vala_ccode_node_unref (_tmp27), NULL));
-		_tmp29 = NULL;
-		_tmp28 = NULL;
-		rhs = (_tmp29 = (_tmp28 = (ValaCCodeExpression*) ccomma, (_tmp28 == NULL) ? NULL : vala_ccode_node_ref (_tmp28)), (rhs == NULL) ? NULL : (rhs = (vala_ccode_node_unref (rhs), NULL)), _tmp29);
+		_tmp30 = NULL;
+		vala_ccode_comma_expression_append_expression (ccomma, _tmp30 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) temp_decl)));
+		(_tmp30 == NULL) ? NULL : (_tmp30 = (vala_ccode_node_unref (_tmp30), NULL));
+		_tmp32 = NULL;
+		_tmp31 = NULL;
+		rhs = (_tmp32 = (_tmp31 = (ValaCCodeExpression*) ccomma, (_tmp31 == NULL) ? NULL : vala_ccode_node_ref (_tmp31)), (rhs == NULL) ? NULL : (rhs = (vala_ccode_node_unref (rhs), NULL)), _tmp32);
 		(ccomma == NULL) ? NULL : (ccomma = (vala_ccode_node_unref (ccomma), NULL));
 		(temp_decl == NULL) ? NULL : (temp_decl = (vala_code_node_unref (temp_decl), NULL));
 	}
@@ -462,15 +480,15 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_simple_assignment
 	}
 	codenode = (ValaCCodeExpression*) vala_ccode_assignment_new (lhs, rhs, cop);
 	if (outer_ccomma != NULL) {
-		ValaCCodeExpression* _tmp31;
-		ValaCCodeExpression* _tmp30;
+		ValaCCodeExpression* _tmp34;
+		ValaCCodeExpression* _tmp33;
 		vala_ccode_comma_expression_append_expression (outer_ccomma, codenode);
-		_tmp31 = NULL;
-		_tmp30 = NULL;
-		codenode = (_tmp31 = (_tmp30 = (ValaCCodeExpression*) outer_ccomma, (_tmp30 == NULL) ? NULL : vala_ccode_node_ref (_tmp30)), (codenode == NULL) ? NULL : (codenode = (vala_ccode_node_unref (codenode), NULL)), _tmp31);
+		_tmp34 = NULL;
+		_tmp33 = NULL;
+		codenode = (_tmp34 = (_tmp33 = (ValaCCodeExpression*) outer_ccomma, (_tmp33 == NULL) ? NULL : vala_ccode_node_ref (_tmp33)), (codenode == NULL) ? NULL : (codenode = (vala_ccode_node_unref (codenode), NULL)), _tmp34);
 	}
-	_tmp32 = NULL;
-	return (_tmp32 = codenode, (rhs == NULL) ? NULL : (rhs = (vala_ccode_node_unref (rhs), NULL)), (lhs == NULL) ? NULL : (lhs = (vala_ccode_node_unref (lhs), NULL)), (outer_ccomma == NULL) ? NULL : (outer_ccomma = (vala_ccode_node_unref (outer_ccomma), NULL)), _tmp32);
+	_tmp35 = NULL;
+	return (_tmp35 = codenode, (rhs == NULL) ? NULL : (rhs = (vala_ccode_node_unref (rhs), NULL)), (lhs == NULL) ? NULL : (lhs = (vala_ccode_node_unref (lhs), NULL)), (outer_ccomma == NULL) ? NULL : (outer_ccomma = (vala_ccode_node_unref (outer_ccomma), NULL)), _tmp35);
 }
 
 
