@@ -36,7 +36,6 @@
 #include <ccode/valaccodetypedefinition.h>
 #include <ccode/valaccodedeclarator.h>
 #include <vala/valasourcereference.h>
-#include <ccode/valaccodefragment.h>
 #include <ccode/valaccodecomment.h>
 #include <ccode/valaccodenode.h>
 #include <vala/valaunaryexpression.h>
@@ -66,7 +65,9 @@
 #include <vala/valavoidtype.h>
 #include <ccode/valaccodeexpressionstatement.h>
 #include <ccode/valaccodereturnstatement.h>
+#include <ccode/valaccodefragment.h>
 #include <gobject/valaccodebasemodule.h>
+#include <gobject/valaccodedeclarationspace.h>
 #include <gobject/valaccodemethodmodule.h>
 
 
@@ -223,10 +224,10 @@ static void vala_ccode_delegate_module_real_visit_delegate (ValaCCodeModule* bas
 		if (_tmp17) {
 			ValaCCodeComment* _tmp18;
 			_tmp18 = NULL;
-			vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_declaration, (ValaCCodeNode*) (_tmp18 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) d)))));
+			vala_ccode_declaration_space_add_type_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp18 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) d)))));
 			(_tmp18 == NULL) ? NULL : (_tmp18 = (vala_ccode_node_unref (_tmp18), NULL));
 		}
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_declaration, (ValaCCodeNode*) ctypedef);
+		vala_ccode_declaration_space_add_type_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) ctypedef);
 	} else {
 		gboolean _tmp19;
 		_tmp19 = FALSE;
@@ -238,10 +239,10 @@ static void vala_ccode_delegate_module_real_visit_delegate (ValaCCodeModule* bas
 		if (_tmp19) {
 			ValaCCodeComment* _tmp20;
 			_tmp20 = NULL;
-			vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_declaration, (ValaCCodeNode*) (_tmp20 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) d)))));
+			vala_ccode_declaration_space_add_type_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp20 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) d)))));
 			(_tmp20 == NULL) ? NULL : (_tmp20 = (vala_ccode_node_unref (_tmp20), NULL));
 		}
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_declaration, (ValaCCodeNode*) ctypedef);
+		vala_ccode_declaration_space_add_type_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) ctypedef);
 	}
 	(cfundecl == NULL) ? NULL : (cfundecl = (vala_ccode_node_unref (cfundecl), NULL));
 	(ctypedef == NULL) ? NULL : (ctypedef = (vala_ccode_node_unref (ctypedef), NULL));
@@ -974,7 +975,7 @@ static char* vala_ccode_delegate_module_generate_delegate_wrapper (ValaCCodeDele
 	}
 	/* append to file*/
 	_tmp74 = NULL;
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp74 = vala_ccode_function_copy (function)));
+	vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp74 = vala_ccode_function_copy (function)));
 	(_tmp74 == NULL) ? NULL : (_tmp74 = (vala_ccode_node_unref (_tmp74), NULL));
 	vala_ccode_function_set_block (function, block);
 	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_definition, (ValaCCodeNode*) function);
