@@ -60,6 +60,7 @@
 #include <ccode/valaccodefunctioncall.h>
 #include <ccode/valaccodeconstant.h>
 #include <ccode/valaccodereturnstatement.h>
+#include <gobject/valaccodedeclarationspace.h>
 
 
 
@@ -103,15 +104,14 @@ static void vala_ccode_struct_module_real_visit_struct (ValaCCodeModule* base, V
 	char* _tmp6;
 	char* _tmp5;
 	ValaCCodeFragment* _tmp8;
-	ValaCCodeFragment* decl_frag;
-	ValaCCodeFragment* def_frag;
-	gboolean _tmp17;
-	ValaTypeSymbol* _tmp25;
-	ValaTypeSymbol* _tmp24;
-	ValaCCodeStruct* _tmp27;
-	ValaCCodeStruct* _tmp26;
-	ValaCCodeFragment* _tmp29;
-	ValaCCodeFragment* _tmp28;
+	ValaCCodeDeclarationSpace* decl_space;
+	gboolean _tmp13;
+	ValaTypeSymbol* _tmp21;
+	ValaTypeSymbol* _tmp20;
+	ValaCCodeStruct* _tmp23;
+	ValaCCodeStruct* _tmp22;
+	ValaCCodeFragment* _tmp25;
+	ValaCCodeFragment* _tmp24;
 	self = (ValaCCodeStructModule*) base;
 	g_return_if_fail (st != NULL);
 	_tmp0 = NULL;
@@ -131,63 +131,52 @@ static void vala_ccode_struct_module_real_visit_struct (ValaCCodeModule* base, V
 	_tmp5 = (g_free (_tmp5), NULL);
 	_tmp8 = NULL;
 	((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (_tmp8 = vala_ccode_fragment_new (), (((ValaCCodeBaseModule*) self)->instance_finalize_fragment == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->instance_finalize_fragment), NULL)), _tmp8);
-	decl_frag = NULL;
-	def_frag = NULL;
+	decl_space = NULL;
 	if (vala_symbol_get_access ((ValaSymbol*) st) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-		ValaCCodeFragment* _tmp10;
-		ValaCCodeFragment* _tmp9;
-		ValaCCodeFragment* _tmp12;
-		ValaCCodeFragment* _tmp11;
+		ValaCCodeDeclarationSpace* _tmp10;
+		ValaCCodeDeclarationSpace* _tmp9;
 		_tmp10 = NULL;
 		_tmp9 = NULL;
-		decl_frag = (_tmp10 = (_tmp9 = ((ValaCCodeBaseModule*) self)->header_type_declaration, (_tmp9 == NULL) ? NULL : vala_ccode_node_ref (_tmp9)), (decl_frag == NULL) ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL)), _tmp10);
+		decl_space = (_tmp10 = (_tmp9 = ((ValaCCodeBaseModule*) self)->header_declarations, (_tmp9 == NULL) ? NULL : vala_ccode_declaration_space_ref (_tmp9)), (decl_space == NULL) ? NULL : (decl_space = (vala_ccode_declaration_space_unref (decl_space), NULL)), _tmp10);
+	} else {
+		ValaCCodeDeclarationSpace* _tmp12;
+		ValaCCodeDeclarationSpace* _tmp11;
 		_tmp12 = NULL;
 		_tmp11 = NULL;
-		def_frag = (_tmp12 = (_tmp11 = ((ValaCCodeBaseModule*) self)->header_type_definition, (_tmp11 == NULL) ? NULL : vala_ccode_node_ref (_tmp11)), (def_frag == NULL) ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL)), _tmp12);
+		decl_space = (_tmp12 = (_tmp11 = ((ValaCCodeBaseModule*) self)->source_declarations, (_tmp11 == NULL) ? NULL : vala_ccode_declaration_space_ref (_tmp11)), (decl_space == NULL) ? NULL : (decl_space = (vala_ccode_declaration_space_unref (decl_space), NULL)), _tmp12);
+	}
+	_tmp13 = FALSE;
+	if (vala_symbol_get_access ((ValaSymbol*) st) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		_tmp13 = TRUE;
 	} else {
-		ValaCCodeFragment* _tmp14;
-		ValaCCodeFragment* _tmp13;
-		ValaCCodeFragment* _tmp16;
-		ValaCCodeFragment* _tmp15;
-		_tmp14 = NULL;
-		_tmp13 = NULL;
-		decl_frag = (_tmp14 = (_tmp13 = ((ValaCCodeBaseModule*) self)->source_type_declaration, (_tmp13 == NULL) ? NULL : vala_ccode_node_ref (_tmp13)), (decl_frag == NULL) ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL)), _tmp14);
+		_tmp13 = vala_source_file_get_cycle (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) st))) == NULL;
+	}
+	if (_tmp13) {
+		ValaCCodeTypeDefinition* _tmp18;
+		ValaCCodeVariableDeclarator* _tmp17;
+		char* _tmp16;
+		char* _tmp15;
+		char* _tmp14;
+		/* no file dependency cycle for private symbols*/
+		_tmp18 = NULL;
+		_tmp17 = NULL;
 		_tmp16 = NULL;
 		_tmp15 = NULL;
-		def_frag = (_tmp16 = (_tmp15 = ((ValaCCodeBaseModule*) self)->source_type_definition, (_tmp15 == NULL) ? NULL : vala_ccode_node_ref (_tmp15)), (def_frag == NULL) ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL)), _tmp16);
-	}
-	_tmp17 = FALSE;
-	if (vala_symbol_get_access ((ValaSymbol*) st) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-		_tmp17 = TRUE;
-	} else {
-		_tmp17 = vala_source_file_get_cycle (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) st))) == NULL;
-	}
-	if (_tmp17) {
-		ValaCCodeTypeDefinition* _tmp22;
-		ValaCCodeVariableDeclarator* _tmp21;
-		char* _tmp20;
-		char* _tmp19;
-		char* _tmp18;
-		/* no file dependency cycle for private symbols*/
-		_tmp22 = NULL;
-		_tmp21 = NULL;
-		_tmp20 = NULL;
-		_tmp19 = NULL;
-		_tmp18 = NULL;
-		vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp22 = vala_ccode_type_definition_new (_tmp19 = g_strdup_printf ("struct _%s", _tmp18 = vala_typesymbol_get_cname ((ValaTypeSymbol*) st, FALSE)), (ValaCCodeDeclarator*) (_tmp21 = vala_ccode_variable_declarator_new (_tmp20 = vala_typesymbol_get_cname ((ValaTypeSymbol*) st, FALSE), NULL)))));
-		(_tmp22 == NULL) ? NULL : (_tmp22 = (vala_ccode_node_unref (_tmp22), NULL));
-		(_tmp21 == NULL) ? NULL : (_tmp21 = (vala_ccode_node_unref (_tmp21), NULL));
-		_tmp20 = (g_free (_tmp20), NULL);
-		_tmp19 = (g_free (_tmp19), NULL);
-		_tmp18 = (g_free (_tmp18), NULL);
+		_tmp14 = NULL;
+		vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp18 = vala_ccode_type_definition_new (_tmp15 = g_strdup_printf ("struct _%s", _tmp14 = vala_typesymbol_get_cname ((ValaTypeSymbol*) st, FALSE)), (ValaCCodeDeclarator*) (_tmp17 = vala_ccode_variable_declarator_new (_tmp16 = vala_typesymbol_get_cname ((ValaTypeSymbol*) st, FALSE), NULL)))));
+		(_tmp18 == NULL) ? NULL : (_tmp18 = (vala_ccode_node_unref (_tmp18), NULL));
+		(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL));
+		_tmp16 = (g_free (_tmp16), NULL);
+		_tmp15 = (g_free (_tmp15), NULL);
+		_tmp14 = (g_free (_tmp14), NULL);
 	}
 	if (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) st)) != NULL) {
-		ValaCCodeComment* _tmp23;
-		_tmp23 = NULL;
-		vala_ccode_fragment_append (def_frag, (ValaCCodeNode*) (_tmp23 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) st)))));
-		(_tmp23 == NULL) ? NULL : (_tmp23 = (vala_ccode_node_unref (_tmp23), NULL));
+		ValaCCodeComment* _tmp19;
+		_tmp19 = NULL;
+		vala_ccode_declaration_space_add_type_definition (decl_space, (ValaCCodeNode*) (_tmp19 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) st)))));
+		(_tmp19 == NULL) ? NULL : (_tmp19 = (vala_ccode_node_unref (_tmp19), NULL));
 	}
-	vala_ccode_fragment_append (def_frag, (ValaCCodeNode*) ((ValaCCodeBaseModule*) self)->instance_struct);
+	vala_ccode_declaration_space_add_type_definition (decl_space, (ValaCCodeNode*) ((ValaCCodeBaseModule*) self)->instance_struct);
 	vala_code_node_accept_children ((ValaCodeNode*) st, (ValaCodeVisitor*) vala_ccode_module_get_codegen ((ValaCCodeModule*) self));
 	if (vala_struct_is_disposable (st)) {
 		vala_ccode_struct_module_add_struct_copy_function (self, st);
@@ -195,20 +184,19 @@ static void vala_ccode_struct_module_real_visit_struct (ValaCCodeModule* base, V
 	}
 	vala_ccode_struct_module_add_struct_dup_function (self, st);
 	vala_ccode_struct_module_add_struct_free_function (self, st);
+	_tmp21 = NULL;
+	_tmp20 = NULL;
+	((ValaCCodeBaseModule*) self)->current_type_symbol = (_tmp21 = (_tmp20 = old_type_symbol, (_tmp20 == NULL) ? NULL : vala_code_node_ref (_tmp20)), (((ValaCCodeBaseModule*) self)->current_type_symbol == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->current_type_symbol = (vala_code_node_unref (((ValaCCodeBaseModule*) self)->current_type_symbol), NULL)), _tmp21);
+	_tmp23 = NULL;
+	_tmp22 = NULL;
+	((ValaCCodeBaseModule*) self)->instance_struct = (_tmp23 = (_tmp22 = old_instance_struct, (_tmp22 == NULL) ? NULL : vala_ccode_node_ref (_tmp22)), (((ValaCCodeBaseModule*) self)->instance_struct == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->instance_struct = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->instance_struct), NULL)), _tmp23);
 	_tmp25 = NULL;
 	_tmp24 = NULL;
-	((ValaCCodeBaseModule*) self)->current_type_symbol = (_tmp25 = (_tmp24 = old_type_symbol, (_tmp24 == NULL) ? NULL : vala_code_node_ref (_tmp24)), (((ValaCCodeBaseModule*) self)->current_type_symbol == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->current_type_symbol = (vala_code_node_unref (((ValaCCodeBaseModule*) self)->current_type_symbol), NULL)), _tmp25);
-	_tmp27 = NULL;
-	_tmp26 = NULL;
-	((ValaCCodeBaseModule*) self)->instance_struct = (_tmp27 = (_tmp26 = old_instance_struct, (_tmp26 == NULL) ? NULL : vala_ccode_node_ref (_tmp26)), (((ValaCCodeBaseModule*) self)->instance_struct == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->instance_struct = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->instance_struct), NULL)), _tmp27);
-	_tmp29 = NULL;
-	_tmp28 = NULL;
-	((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (_tmp29 = (_tmp28 = old_instance_finalize_fragment, (_tmp28 == NULL) ? NULL : vala_ccode_node_ref (_tmp28)), (((ValaCCodeBaseModule*) self)->instance_finalize_fragment == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->instance_finalize_fragment), NULL)), _tmp29);
+	((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (_tmp25 = (_tmp24 = old_instance_finalize_fragment, (_tmp24 == NULL) ? NULL : vala_ccode_node_ref (_tmp24)), (((ValaCCodeBaseModule*) self)->instance_finalize_fragment == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->instance_finalize_fragment), NULL)), _tmp25);
 	(old_type_symbol == NULL) ? NULL : (old_type_symbol = (vala_code_node_unref (old_type_symbol), NULL));
 	(old_instance_struct == NULL) ? NULL : (old_instance_struct = (vala_ccode_node_unref (old_instance_struct), NULL));
 	(old_instance_finalize_fragment == NULL) ? NULL : (old_instance_finalize_fragment = (vala_ccode_node_unref (old_instance_finalize_fragment), NULL));
-	(decl_frag == NULL) ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL));
-	(def_frag == NULL) ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL));
+	(decl_space == NULL) ? NULL : (decl_space = (vala_ccode_declaration_space_unref (decl_space), NULL));
 }
 
 
@@ -261,12 +249,12 @@ static void vala_ccode_struct_module_add_struct_dup_function (ValaCCodeStructMod
 	if (vala_symbol_get_access ((ValaSymbol*) st) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		ValaCCodeFunction* _tmp8;
 		_tmp8 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_member_declaration, (ValaCCodeNode*) (_tmp8 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp8 = vala_ccode_function_copy (function)));
 		(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL));
 	} else {
 		ValaCCodeFunction* _tmp9;
 		_tmp9 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp9 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp9 = vala_ccode_function_copy (function)));
 		(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
 	}
 	cblock = vala_ccode_block_new ();
@@ -399,12 +387,12 @@ static void vala_ccode_struct_module_add_struct_free_function (ValaCCodeStructMo
 	if (vala_symbol_get_access ((ValaSymbol*) st) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		ValaCCodeFunction* _tmp5;
 		_tmp5 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_member_declaration, (ValaCCodeNode*) (_tmp5 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp5 = vala_ccode_function_copy (function)));
 		(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL));
 	} else {
 		ValaCCodeFunction* _tmp6;
 		_tmp6 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp6 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp6 = vala_ccode_function_copy (function)));
 		(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL));
 	}
 	cblock = vala_ccode_block_new ();
@@ -484,12 +472,12 @@ static void vala_ccode_struct_module_add_struct_copy_function (ValaCCodeStructMo
 	if (vala_symbol_get_access ((ValaSymbol*) st) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		ValaCCodeFunction* _tmp9;
 		_tmp9 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_member_declaration, (ValaCCodeNode*) (_tmp9 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp9 = vala_ccode_function_copy (function)));
 		(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
 	} else {
 		ValaCCodeFunction* _tmp10;
 		_tmp10 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp10 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp10 = vala_ccode_function_copy (function)));
 		(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL));
 	}
 	cblock = vala_ccode_block_new ();
@@ -628,12 +616,12 @@ static void vala_ccode_struct_module_add_struct_destroy_function (ValaCCodeStruc
 	if (vala_symbol_get_access ((ValaSymbol*) st) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		ValaCCodeFunction* _tmp5;
 		_tmp5 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_member_declaration, (ValaCCodeNode*) (_tmp5 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp5 = vala_ccode_function_copy (function)));
 		(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL));
 	} else {
 		ValaCCodeFunction* _tmp6;
 		_tmp6 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp6 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp6 = vala_ccode_function_copy (function)));
 		(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL));
 	}
 	cblock = vala_ccode_block_new ();
