@@ -28,7 +28,6 @@
 #include <vala/valacodenode.h>
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
-#include <ccode/valaccodefragment.h>
 #include <vala/valasymbol.h>
 #include <ccode/valaccodestruct.h>
 #include <ccode/valaccodenewline.h>
@@ -63,8 +62,10 @@
 #include <vala/valasignal.h>
 #include <vala/valamethod.h>
 #include <ccode/valaccodememberaccess.h>
+#include <ccode/valaccodefragment.h>
 #include <vala/valacodecontext.h>
 #include <gobject/valaccodebasemodule.h>
+#include <gobject/valaccodedeclarationspace.h>
 #include <gobject/valainterfaceregisterfunction.h>
 #include <gobject/valatyperegisterfunction.h>
 #include <gobject/valastructregisterfunction.h>
@@ -103,38 +104,37 @@ static void vala_gtype_module_real_visit_interface (ValaCCodeModule* base, ValaI
 	ValaTypeSymbol* _tmp2;
 	char* _tmp4;
 	gboolean _tmp5;
-	ValaCCodeFragment* decl_frag;
-	ValaCCodeFragment* def_frag;
-	ValaCCodeStruct* _tmp18;
-	char* _tmp17;
+	ValaCCodeDeclarationSpace* decl_space;
+	ValaCCodeStruct* _tmp14;
+	char* _tmp13;
+	char* _tmp12;
+	ValaCCodeNewline* _tmp15;
 	char* _tmp16;
-	ValaCCodeNewline* _tmp19;
-	char* _tmp20;
-	char* _tmp21;
+	char* _tmp17;
 	char* macro;
-	ValaCCodeMacroReplacement* _tmp23;
+	ValaCCodeMacroReplacement* _tmp19;
+	char* _tmp18;
 	char* _tmp22;
-	char* _tmp26;
-	char* _tmp25;
+	char* _tmp21;
+	char* _tmp20;
+	ValaCCodeMacroReplacement* _tmp25;
 	char* _tmp24;
-	ValaCCodeMacroReplacement* _tmp29;
-	char* _tmp28;
+	char* _tmp23;
 	char* _tmp27;
-	char* _tmp31;
-	char* _tmp30;
-	ValaCCodeMacroReplacement* _tmp34;
+	char* _tmp26;
+	ValaCCodeMacroReplacement* _tmp30;
+	char* _tmp29;
+	char* _tmp28;
 	char* _tmp33;
 	char* _tmp32;
-	char* _tmp37;
-	char* _tmp36;
+	char* _tmp31;
+	ValaCCodeMacroReplacement* _tmp36;
 	char* _tmp35;
-	ValaCCodeMacroReplacement* _tmp40;
-	char* _tmp39;
-	char* _tmp38;
-	ValaCCodeNewline* _tmp41;
+	char* _tmp34;
+	ValaCCodeNewline* _tmp37;
 	ValaInterfaceRegisterFunction* type_fun;
-	ValaCCodeFragment* _tmp54;
-	ValaTypeSymbol* _tmp55;
+	ValaCCodeFragment* _tmp50;
+	ValaTypeSymbol* _tmp51;
 	self = (ValaGTypeModule*) base;
 	g_return_if_fail (iface != NULL);
 	_tmp1 = NULL;
@@ -155,149 +155,137 @@ static void vala_gtype_module_real_visit_interface (ValaCCodeModule* base, ValaI
 		_tmp6 = (g_free (_tmp6), NULL);
 		return;
 	}
-	decl_frag = NULL;
-	def_frag = NULL;
+	decl_space = NULL;
 	if (vala_symbol_get_access ((ValaSymbol*) iface) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-		ValaCCodeFragment* _tmp9;
-		ValaCCodeFragment* _tmp8;
-		ValaCCodeFragment* _tmp11;
-		ValaCCodeFragment* _tmp10;
+		ValaCCodeDeclarationSpace* _tmp9;
+		ValaCCodeDeclarationSpace* _tmp8;
 		_tmp9 = NULL;
 		_tmp8 = NULL;
-		decl_frag = (_tmp9 = (_tmp8 = ((ValaCCodeBaseModule*) self)->header_type_declaration, (_tmp8 == NULL) ? NULL : vala_ccode_node_ref (_tmp8)), (decl_frag == NULL) ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL)), _tmp9);
+		decl_space = (_tmp9 = (_tmp8 = ((ValaCCodeBaseModule*) self)->header_declarations, (_tmp8 == NULL) ? NULL : vala_ccode_declaration_space_ref (_tmp8)), (decl_space == NULL) ? NULL : (decl_space = (vala_ccode_declaration_space_unref (decl_space), NULL)), _tmp9);
+	} else {
+		ValaCCodeDeclarationSpace* _tmp11;
+		ValaCCodeDeclarationSpace* _tmp10;
 		_tmp11 = NULL;
 		_tmp10 = NULL;
-		def_frag = (_tmp11 = (_tmp10 = ((ValaCCodeBaseModule*) self)->header_type_definition, (_tmp10 == NULL) ? NULL : vala_ccode_node_ref (_tmp10)), (def_frag == NULL) ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL)), _tmp11);
-	} else {
-		ValaCCodeFragment* _tmp13;
-		ValaCCodeFragment* _tmp12;
-		ValaCCodeFragment* _tmp15;
-		ValaCCodeFragment* _tmp14;
-		_tmp13 = NULL;
-		_tmp12 = NULL;
-		decl_frag = (_tmp13 = (_tmp12 = ((ValaCCodeBaseModule*) self)->source_type_declaration, (_tmp12 == NULL) ? NULL : vala_ccode_node_ref (_tmp12)), (decl_frag == NULL) ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL)), _tmp13);
-		_tmp15 = NULL;
-		_tmp14 = NULL;
-		def_frag = (_tmp15 = (_tmp14 = ((ValaCCodeBaseModule*) self)->source_type_definition, (_tmp14 == NULL) ? NULL : vala_ccode_node_ref (_tmp14)), (def_frag == NULL) ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL)), _tmp15);
+		decl_space = (_tmp11 = (_tmp10 = ((ValaCCodeBaseModule*) self)->source_declarations, (_tmp10 == NULL) ? NULL : vala_ccode_declaration_space_ref (_tmp10)), (decl_space == NULL) ? NULL : (decl_space = (vala_ccode_declaration_space_unref (decl_space), NULL)), _tmp11);
 	}
-	_tmp18 = NULL;
-	_tmp17 = NULL;
+	_tmp14 = NULL;
+	_tmp13 = NULL;
+	_tmp12 = NULL;
+	((ValaCCodeBaseModule*) self)->type_struct = (_tmp14 = vala_ccode_struct_new (_tmp13 = g_strdup_printf ("_%s", _tmp12 = vala_interface_get_type_cname (iface))), (((ValaCCodeBaseModule*) self)->type_struct == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->type_struct = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->type_struct), NULL)), _tmp14);
+	_tmp13 = (g_free (_tmp13), NULL);
+	_tmp12 = (g_free (_tmp12), NULL);
+	_tmp15 = NULL;
+	vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp15 = vala_ccode_newline_new ()));
+	(_tmp15 == NULL) ? NULL : (_tmp15 = (vala_ccode_node_unref (_tmp15), NULL));
 	_tmp16 = NULL;
-	((ValaCCodeBaseModule*) self)->type_struct = (_tmp18 = vala_ccode_struct_new (_tmp17 = g_strdup_printf ("_%s", _tmp16 = vala_interface_get_type_cname (iface))), (((ValaCCodeBaseModule*) self)->type_struct == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->type_struct = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->type_struct), NULL)), _tmp18);
-	_tmp17 = (g_free (_tmp17), NULL);
-	_tmp16 = (g_free (_tmp16), NULL);
+	_tmp17 = NULL;
+	macro = (_tmp17 = g_strdup_printf ("(%s_get_type ())", _tmp16 = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _tmp16 = (g_free (_tmp16), NULL), _tmp17);
 	_tmp19 = NULL;
-	vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp19 = vala_ccode_newline_new ()));
+	_tmp18 = NULL;
+	vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp19 = vala_ccode_macro_replacement_new (_tmp18 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface), macro)));
 	(_tmp19 == NULL) ? NULL : (_tmp19 = (vala_ccode_node_unref (_tmp19), NULL));
-	_tmp20 = NULL;
-	_tmp21 = NULL;
-	macro = (_tmp21 = g_strdup_printf ("(%s_get_type ())", _tmp20 = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _tmp20 = (g_free (_tmp20), NULL), _tmp21);
-	_tmp23 = NULL;
+	_tmp18 = (g_free (_tmp18), NULL);
 	_tmp22 = NULL;
-	vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp23 = vala_ccode_macro_replacement_new (_tmp22 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface), macro)));
-	(_tmp23 == NULL) ? NULL : (_tmp23 = (vala_ccode_node_unref (_tmp23), NULL));
-	_tmp22 = (g_free (_tmp22), NULL);
-	_tmp26 = NULL;
+	_tmp21 = NULL;
+	_tmp20 = NULL;
+	macro = (_tmp22 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_CAST ((obj), %s, %s))", _tmp20 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface), _tmp21 = vala_typesymbol_get_cname ((ValaTypeSymbol*) iface, FALSE)), macro = (g_free (macro), NULL), _tmp22);
+	_tmp21 = (g_free (_tmp21), NULL);
+	_tmp20 = (g_free (_tmp20), NULL);
 	_tmp25 = NULL;
 	_tmp24 = NULL;
-	macro = (_tmp26 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_CAST ((obj), %s, %s))", _tmp24 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface), _tmp25 = vala_typesymbol_get_cname ((ValaTypeSymbol*) iface, FALSE)), macro = (g_free (macro), NULL), _tmp26);
-	_tmp25 = (g_free (_tmp25), NULL);
+	_tmp23 = NULL;
+	vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp25 = vala_ccode_macro_replacement_new (_tmp24 = g_strdup_printf ("%s(obj)", _tmp23 = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) iface, NULL)), macro)));
+	(_tmp25 == NULL) ? NULL : (_tmp25 = (vala_ccode_node_unref (_tmp25), NULL));
 	_tmp24 = (g_free (_tmp24), NULL);
+	_tmp23 = (g_free (_tmp23), NULL);
+	_tmp27 = NULL;
+	_tmp26 = NULL;
+	macro = (_tmp27 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_TYPE ((obj), %s))", _tmp26 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface)), macro = (g_free (macro), NULL), _tmp27);
+	_tmp26 = (g_free (_tmp26), NULL);
+	_tmp30 = NULL;
 	_tmp29 = NULL;
 	_tmp28 = NULL;
-	_tmp27 = NULL;
-	vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp29 = vala_ccode_macro_replacement_new (_tmp28 = g_strdup_printf ("%s(obj)", _tmp27 = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) iface, NULL)), macro)));
-	(_tmp29 == NULL) ? NULL : (_tmp29 = (vala_ccode_node_unref (_tmp29), NULL));
+	vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp30 = vala_ccode_macro_replacement_new (_tmp29 = g_strdup_printf ("%s(obj)", _tmp28 = vala_ccode_base_module_get_type_check_function ((ValaCCodeBaseModule*) self, (ValaTypeSymbol*) iface)), macro)));
+	(_tmp30 == NULL) ? NULL : (_tmp30 = (vala_ccode_node_unref (_tmp30), NULL));
+	_tmp29 = (g_free (_tmp29), NULL);
 	_tmp28 = (g_free (_tmp28), NULL);
-	_tmp27 = (g_free (_tmp27), NULL);
-	_tmp31 = NULL;
-	_tmp30 = NULL;
-	macro = (_tmp31 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_TYPE ((obj), %s))", _tmp30 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface)), macro = (g_free (macro), NULL), _tmp31);
-	_tmp30 = (g_free (_tmp30), NULL);
-	_tmp34 = NULL;
 	_tmp33 = NULL;
 	_tmp32 = NULL;
-	vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp34 = vala_ccode_macro_replacement_new (_tmp33 = g_strdup_printf ("%s(obj)", _tmp32 = vala_ccode_base_module_get_type_check_function ((ValaCCodeBaseModule*) self, (ValaTypeSymbol*) iface)), macro)));
-	(_tmp34 == NULL) ? NULL : (_tmp34 = (vala_ccode_node_unref (_tmp34), NULL));
-	_tmp33 = (g_free (_tmp33), NULL);
+	_tmp31 = NULL;
+	macro = (_tmp33 = g_strdup_printf ("(G_TYPE_INSTANCE_GET_INTERFACE ((obj), %s, %s))", _tmp31 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface), _tmp32 = vala_interface_get_type_cname (iface)), macro = (g_free (macro), NULL), _tmp33);
 	_tmp32 = (g_free (_tmp32), NULL);
-	_tmp37 = NULL;
+	_tmp31 = (g_free (_tmp31), NULL);
 	_tmp36 = NULL;
 	_tmp35 = NULL;
-	macro = (_tmp37 = g_strdup_printf ("(G_TYPE_INSTANCE_GET_INTERFACE ((obj), %s, %s))", _tmp35 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface), _tmp36 = vala_interface_get_type_cname (iface)), macro = (g_free (macro), NULL), _tmp37);
-	_tmp36 = (g_free (_tmp36), NULL);
+	_tmp34 = NULL;
+	vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp36 = vala_ccode_macro_replacement_new (_tmp35 = g_strdup_printf ("%s_GET_INTERFACE(obj)", _tmp34 = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) iface, NULL)), macro)));
+	(_tmp36 == NULL) ? NULL : (_tmp36 = (vala_ccode_node_unref (_tmp36), NULL));
 	_tmp35 = (g_free (_tmp35), NULL);
-	_tmp40 = NULL;
-	_tmp39 = NULL;
-	_tmp38 = NULL;
-	vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp40 = vala_ccode_macro_replacement_new (_tmp39 = g_strdup_printf ("%s_GET_INTERFACE(obj)", _tmp38 = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) iface, NULL)), macro)));
-	(_tmp40 == NULL) ? NULL : (_tmp40 = (vala_ccode_node_unref (_tmp40), NULL));
-	_tmp39 = (g_free (_tmp39), NULL);
-	_tmp38 = (g_free (_tmp38), NULL);
-	_tmp41 = NULL;
-	vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp41 = vala_ccode_newline_new ()));
-	(_tmp41 == NULL) ? NULL : (_tmp41 = (vala_ccode_node_unref (_tmp41), NULL));
+	_tmp34 = (g_free (_tmp34), NULL);
+	_tmp37 = NULL;
+	vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp37 = vala_ccode_newline_new ()));
+	(_tmp37 == NULL) ? NULL : (_tmp37 = (vala_ccode_node_unref (_tmp37), NULL));
 	if (vala_source_file_get_cycle (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) iface))) == NULL) {
+		ValaCCodeTypeDefinition* _tmp42;
+		ValaCCodeVariableDeclarator* _tmp41;
+		char* _tmp40;
+		char* _tmp39;
+		char* _tmp38;
 		ValaCCodeTypeDefinition* _tmp46;
 		ValaCCodeVariableDeclarator* _tmp45;
 		char* _tmp44;
 		char* _tmp43;
-		char* _tmp42;
-		ValaCCodeTypeDefinition* _tmp50;
-		ValaCCodeVariableDeclarator* _tmp49;
-		char* _tmp48;
-		char* _tmp47;
+		_tmp42 = NULL;
+		_tmp41 = NULL;
+		_tmp40 = NULL;
+		_tmp39 = NULL;
+		_tmp38 = NULL;
+		vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp42 = vala_ccode_type_definition_new (_tmp39 = g_strdup_printf ("struct _%s", _tmp38 = vala_typesymbol_get_cname ((ValaTypeSymbol*) iface, FALSE)), (ValaCCodeDeclarator*) (_tmp41 = vala_ccode_variable_declarator_new (_tmp40 = vala_typesymbol_get_cname ((ValaTypeSymbol*) iface, FALSE), NULL)))));
+		(_tmp42 == NULL) ? NULL : (_tmp42 = (vala_ccode_node_unref (_tmp42), NULL));
+		(_tmp41 == NULL) ? NULL : (_tmp41 = (vala_ccode_node_unref (_tmp41), NULL));
+		_tmp40 = (g_free (_tmp40), NULL);
+		_tmp39 = (g_free (_tmp39), NULL);
+		_tmp38 = (g_free (_tmp38), NULL);
 		_tmp46 = NULL;
 		_tmp45 = NULL;
 		_tmp44 = NULL;
 		_tmp43 = NULL;
-		_tmp42 = NULL;
-		vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp46 = vala_ccode_type_definition_new (_tmp43 = g_strdup_printf ("struct _%s", _tmp42 = vala_typesymbol_get_cname ((ValaTypeSymbol*) iface, FALSE)), (ValaCCodeDeclarator*) (_tmp45 = vala_ccode_variable_declarator_new (_tmp44 = vala_typesymbol_get_cname ((ValaTypeSymbol*) iface, FALSE), NULL)))));
+		vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp46 = vala_ccode_type_definition_new (_tmp43 = g_strdup_printf ("struct %s", vala_ccode_struct_get_name (((ValaCCodeBaseModule*) self)->type_struct)), (ValaCCodeDeclarator*) (_tmp45 = vala_ccode_variable_declarator_new (_tmp44 = vala_interface_get_type_cname (iface), NULL)))));
 		(_tmp46 == NULL) ? NULL : (_tmp46 = (vala_ccode_node_unref (_tmp46), NULL));
 		(_tmp45 == NULL) ? NULL : (_tmp45 = (vala_ccode_node_unref (_tmp45), NULL));
 		_tmp44 = (g_free (_tmp44), NULL);
 		_tmp43 = (g_free (_tmp43), NULL);
-		_tmp42 = (g_free (_tmp42), NULL);
-		_tmp50 = NULL;
-		_tmp49 = NULL;
-		_tmp48 = NULL;
-		_tmp47 = NULL;
-		vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp50 = vala_ccode_type_definition_new (_tmp47 = g_strdup_printf ("struct %s", vala_ccode_struct_get_name (((ValaCCodeBaseModule*) self)->type_struct)), (ValaCCodeDeclarator*) (_tmp49 = vala_ccode_variable_declarator_new (_tmp48 = vala_interface_get_type_cname (iface), NULL)))));
-		(_tmp50 == NULL) ? NULL : (_tmp50 = (vala_ccode_node_unref (_tmp50), NULL));
-		(_tmp49 == NULL) ? NULL : (_tmp49 = (vala_ccode_node_unref (_tmp49), NULL));
-		_tmp48 = (g_free (_tmp48), NULL);
-		_tmp47 = (g_free (_tmp47), NULL);
 	}
 	vala_ccode_struct_add_field (((ValaCCodeBaseModule*) self)->type_struct, "GTypeInterface", "parent_iface");
 	if (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) iface)) != NULL) {
-		ValaCCodeComment* _tmp51;
-		_tmp51 = NULL;
-		vala_ccode_fragment_append (def_frag, (ValaCCodeNode*) (_tmp51 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) iface)))));
-		(_tmp51 == NULL) ? NULL : (_tmp51 = (vala_ccode_node_unref (_tmp51), NULL));
+		ValaCCodeComment* _tmp47;
+		_tmp47 = NULL;
+		vala_ccode_declaration_space_add_type_definition (decl_space, (ValaCCodeNode*) (_tmp47 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) iface)))));
+		(_tmp47 == NULL) ? NULL : (_tmp47 = (vala_ccode_node_unref (_tmp47), NULL));
 	}
-	vala_ccode_fragment_append (def_frag, (ValaCCodeNode*) ((ValaCCodeBaseModule*) self)->type_struct);
+	vala_ccode_declaration_space_add_type_definition (decl_space, (ValaCCodeNode*) ((ValaCCodeBaseModule*) self)->type_struct);
 	vala_code_node_accept_children ((ValaCodeNode*) iface, (ValaCodeVisitor*) vala_ccode_module_get_codegen ((ValaCCodeModule*) self));
 	vala_gtype_module_add_interface_base_init_function (self, iface);
 	type_fun = vala_interface_register_function_new (iface, vala_ccode_base_module_get_context ((ValaCCodeBaseModule*) self));
 	vala_typeregister_function_init_from_type ((ValaTypeRegisterFunction*) type_fun, FALSE);
 	if (vala_symbol_get_access ((ValaSymbol*) iface) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-		ValaCCodeFragment* _tmp52;
-		_tmp52 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_member_declaration, (ValaCCodeNode*) (_tmp52 = vala_typeregister_function_get_declaration ((ValaTypeRegisterFunction*) type_fun)));
-		(_tmp52 == NULL) ? NULL : (_tmp52 = (vala_ccode_node_unref (_tmp52), NULL));
+		ValaCCodeFragment* _tmp48;
+		_tmp48 = NULL;
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp48 = vala_typeregister_function_get_declaration ((ValaTypeRegisterFunction*) type_fun)));
+		(_tmp48 == NULL) ? NULL : (_tmp48 = (vala_ccode_node_unref (_tmp48), NULL));
 	} else {
-		ValaCCodeFragment* _tmp53;
-		_tmp53 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp53 = vala_typeregister_function_get_declaration ((ValaTypeRegisterFunction*) type_fun)));
-		(_tmp53 == NULL) ? NULL : (_tmp53 = (vala_ccode_node_unref (_tmp53), NULL));
+		ValaCCodeFragment* _tmp49;
+		_tmp49 = NULL;
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp49 = vala_typeregister_function_get_declaration ((ValaTypeRegisterFunction*) type_fun)));
+		(_tmp49 == NULL) ? NULL : (_tmp49 = (vala_ccode_node_unref (_tmp49), NULL));
 	}
-	_tmp54 = NULL;
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_definition, (ValaCCodeNode*) (_tmp54 = vala_typeregister_function_get_definition ((ValaTypeRegisterFunction*) type_fun)));
-	(_tmp54 == NULL) ? NULL : (_tmp54 = (vala_ccode_node_unref (_tmp54), NULL));
-	_tmp55 = NULL;
-	((ValaCCodeBaseModule*) self)->current_type_symbol = (_tmp55 = NULL, (((ValaCCodeBaseModule*) self)->current_type_symbol == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->current_type_symbol = (vala_code_node_unref (((ValaCCodeBaseModule*) self)->current_type_symbol), NULL)), _tmp55);
-	(decl_frag == NULL) ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL));
-	(def_frag == NULL) ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL));
+	_tmp50 = NULL;
+	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_definition, (ValaCCodeNode*) (_tmp50 = vala_typeregister_function_get_definition ((ValaTypeRegisterFunction*) type_fun)));
+	(_tmp50 == NULL) ? NULL : (_tmp50 = (vala_ccode_node_unref (_tmp50), NULL));
+	_tmp51 = NULL;
+	((ValaCCodeBaseModule*) self)->current_type_symbol = (_tmp51 = NULL, (((ValaCCodeBaseModule*) self)->current_type_symbol == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->current_type_symbol = (vala_code_node_unref (((ValaCCodeBaseModule*) self)->current_type_symbol), NULL)), _tmp51);
+	(decl_space == NULL) ? NULL : (decl_space = (vala_ccode_declaration_space_unref (decl_space), NULL));
 	macro = (g_free (macro), NULL);
 	(type_fun == NULL) ? NULL : (type_fun = (vala_typeregister_function_unref (type_fun), NULL));
 }
@@ -484,7 +472,7 @@ static void vala_gtype_module_add_interface_base_init_function (ValaGTypeModule*
 
 static void vala_gtype_module_real_visit_struct (ValaCCodeModule* base, ValaStruct* st) {
 	ValaGTypeModule * self;
-	ValaCCodeFragment* decl_frag;
+	ValaCCodeDeclarationSpace* decl_space;
 	ValaCCodeNewline* _tmp4;
 	char* _tmp5;
 	char* _tmp6;
@@ -496,29 +484,29 @@ static void vala_gtype_module_real_visit_struct (ValaCCodeModule* base, ValaStru
 	self = (ValaGTypeModule*) base;
 	g_return_if_fail (st != NULL);
 	VALA_CCODE_MODULE_CLASS (vala_gtype_module_parent_class)->visit_struct ((ValaCCodeModule*) VALA_GERROR_MODULE (self), st);
-	decl_frag = NULL;
+	decl_space = NULL;
 	if (vala_symbol_get_access ((ValaSymbol*) st) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-		ValaCCodeFragment* _tmp1;
-		ValaCCodeFragment* _tmp0;
+		ValaCCodeDeclarationSpace* _tmp1;
+		ValaCCodeDeclarationSpace* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		decl_frag = (_tmp1 = (_tmp0 = ((ValaCCodeBaseModule*) self)->header_type_declaration, (_tmp0 == NULL) ? NULL : vala_ccode_node_ref (_tmp0)), (decl_frag == NULL) ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL)), _tmp1);
+		decl_space = (_tmp1 = (_tmp0 = ((ValaCCodeBaseModule*) self)->header_declarations, (_tmp0 == NULL) ? NULL : vala_ccode_declaration_space_ref (_tmp0)), (decl_space == NULL) ? NULL : (decl_space = (vala_ccode_declaration_space_unref (decl_space), NULL)), _tmp1);
 	} else {
-		ValaCCodeFragment* _tmp3;
-		ValaCCodeFragment* _tmp2;
+		ValaCCodeDeclarationSpace* _tmp3;
+		ValaCCodeDeclarationSpace* _tmp2;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		decl_frag = (_tmp3 = (_tmp2 = ((ValaCCodeBaseModule*) self)->source_type_declaration, (_tmp2 == NULL) ? NULL : vala_ccode_node_ref (_tmp2)), (decl_frag == NULL) ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL)), _tmp3);
+		decl_space = (_tmp3 = (_tmp2 = ((ValaCCodeBaseModule*) self)->source_declarations, (_tmp2 == NULL) ? NULL : vala_ccode_declaration_space_ref (_tmp2)), (decl_space == NULL) ? NULL : (decl_space = (vala_ccode_declaration_space_unref (decl_space), NULL)), _tmp3);
 	}
 	_tmp4 = NULL;
-	vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp4 = vala_ccode_newline_new ()));
+	vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp4 = vala_ccode_newline_new ()));
 	(_tmp4 == NULL) ? NULL : (_tmp4 = (vala_ccode_node_unref (_tmp4), NULL));
 	_tmp5 = NULL;
 	_tmp6 = NULL;
 	macro = (_tmp6 = g_strdup_printf ("(%s_get_type ())", _tmp5 = vala_symbol_get_lower_case_cname ((ValaSymbol*) st, NULL)), _tmp5 = (g_free (_tmp5), NULL), _tmp6);
 	_tmp8 = NULL;
 	_tmp7 = NULL;
-	vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp8 = vala_ccode_macro_replacement_new (_tmp7 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) st), macro)));
+	vala_ccode_declaration_space_add_type_declaration (decl_space, (ValaCCodeNode*) (_tmp8 = vala_ccode_macro_replacement_new (_tmp7 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) st), macro)));
 	(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL));
 	_tmp7 = (g_free (_tmp7), NULL);
 	type_fun = vala_struct_register_function_new (st, vala_ccode_base_module_get_context ((ValaCCodeBaseModule*) self));
@@ -526,18 +514,18 @@ static void vala_gtype_module_real_visit_struct (ValaCCodeModule* base, ValaStru
 	if (vala_symbol_get_access ((ValaSymbol*) st) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		ValaCCodeFragment* _tmp9;
 		_tmp9 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_member_declaration, (ValaCCodeNode*) (_tmp9 = vala_typeregister_function_get_declaration ((ValaTypeRegisterFunction*) type_fun)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp9 = vala_typeregister_function_get_declaration ((ValaTypeRegisterFunction*) type_fun)));
 		(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
 	} else {
 		ValaCCodeFragment* _tmp10;
 		_tmp10 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp10 = vala_typeregister_function_get_declaration ((ValaTypeRegisterFunction*) type_fun)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp10 = vala_typeregister_function_get_declaration ((ValaTypeRegisterFunction*) type_fun)));
 		(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL));
 	}
 	_tmp11 = NULL;
 	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_definition, (ValaCCodeNode*) (_tmp11 = vala_typeregister_function_get_definition ((ValaTypeRegisterFunction*) type_fun)));
 	(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL));
-	(decl_frag == NULL) ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL));
+	(decl_space == NULL) ? NULL : (decl_space = (vala_ccode_declaration_space_unref (decl_space), NULL));
 	macro = (g_free (macro), NULL);
 	(type_fun == NULL) ? NULL : (type_fun = (vala_typeregister_function_unref (type_fun), NULL));
 }
