@@ -26,6 +26,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valasymbol.h>
+#include <vala/valamember.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -47,17 +48,20 @@ struct _ValaConstructor {
 	ValaSymbol parent_instance;
 	ValaConstructorPrivate * priv;
 };
+
 struct _ValaConstructorClass {
 	ValaSymbolClass parent_class;
 };
 
+
+ValaConstructor* vala_constructor_construct (GType object_type, ValaSourceReference* source);
 ValaConstructor* vala_constructor_new (ValaSourceReference* source);
 ValaBlock* vala_constructor_get_body (ValaConstructor* self);
 void vala_constructor_set_body (ValaConstructor* self, ValaBlock* value);
 ValaFormalParameter* vala_constructor_get_this_parameter (ValaConstructor* self);
 void vala_constructor_set_this_parameter (ValaConstructor* self, ValaFormalParameter* value);
-gboolean vala_constructor_get_instance (ValaConstructor* self);
-void vala_constructor_set_instance (ValaConstructor* self, gboolean value);
+MemberBinding vala_constructor_get_binding (ValaConstructor* self);
+void vala_constructor_set_binding (ValaConstructor* self, MemberBinding value);
 GType vala_constructor_get_type (void);
 
 
