@@ -485,7 +485,7 @@ static char* vala_delegate_get_return_type_string (ValaDelegate* self) {
 	}
 	_tmp3 = NULL;
 	_tmp2 = NULL;
-	str = (_tmp3 = g_strconcat (str, _tmp2 = (vala_code_node_to_string ((ValaCodeNode*) vala_delegate_get_return_type (self))), NULL), str = (g_free (str), NULL), _tmp3);
+	str = (_tmp3 = g_strconcat (str, _tmp2 = vala_code_node_to_string ((ValaCodeNode*) vala_delegate_get_return_type (self)), NULL), str = (g_free (str), NULL), _tmp3);
 	_tmp2 = (g_free (_tmp2), NULL);
 	return str;
 }
@@ -510,19 +510,19 @@ static char* vala_delegate_get_parameters_string (ValaDelegate* self) {
 			if (i > 1) {
 				char* _tmp0;
 				_tmp0 = NULL;
-				str = (_tmp0 = g_strconcat (str, (", "), NULL), str = (g_free (str), NULL), _tmp0);
+				str = (_tmp0 = g_strconcat (str, ", ", NULL), str = (g_free (str), NULL), _tmp0);
 			}
 			if (vala_formal_parameter_get_direction (param) != VALA_PARAMETER_DIRECTION_IN) {
 				gboolean _tmp3;
 				if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_REF) {
 					char* _tmp1;
 					_tmp1 = NULL;
-					str = (_tmp1 = g_strconcat (str, ("ref "), NULL), str = (g_free (str), NULL), _tmp1);
+					str = (_tmp1 = g_strconcat (str, "ref ", NULL), str = (g_free (str), NULL), _tmp1);
 				} else {
 					if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_OUT) {
 						char* _tmp2;
 						_tmp2 = NULL;
-						str = (_tmp2 = g_strconcat (str, ("out "), NULL), str = (g_free (str), NULL), _tmp2);
+						str = (_tmp2 = g_strconcat (str, "out ", NULL), str = (g_free (str), NULL), _tmp2);
 					}
 				}
 				_tmp3 = FALSE;
@@ -534,12 +534,12 @@ static char* vala_delegate_get_parameters_string (ValaDelegate* self) {
 				if (_tmp3) {
 					char* _tmp4;
 					_tmp4 = NULL;
-					str = (_tmp4 = g_strconcat (str, ("weak "), NULL), str = (g_free (str), NULL), _tmp4);
+					str = (_tmp4 = g_strconcat (str, "weak ", NULL), str = (g_free (str), NULL), _tmp4);
 				}
 			}
 			_tmp6 = NULL;
 			_tmp5 = NULL;
-			str = (_tmp6 = g_strconcat (str, _tmp5 = (vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (param))), NULL), str = (g_free (str), NULL), _tmp6);
+			str = (_tmp6 = g_strconcat (str, _tmp5 = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (param)), NULL), str = (g_free (str), NULL), _tmp6);
 			_tmp5 = (g_free (_tmp5), NULL);
 			_tmp7 = FALSE;
 			if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_IN) {
@@ -550,7 +550,7 @@ static char* vala_delegate_get_parameters_string (ValaDelegate* self) {
 			if (_tmp7) {
 				char* _tmp8;
 				_tmp8 = NULL;
-				str = (_tmp8 = g_strconcat (str, ("#"), NULL), str = (g_free (str), NULL), _tmp8);
+				str = (_tmp8 = g_strconcat (str, "#", NULL), str = (g_free (str), NULL), _tmp8);
 			}
 			i++;
 			(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
@@ -558,7 +558,7 @@ static char* vala_delegate_get_parameters_string (ValaDelegate* self) {
 		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
 	}
 	_tmp9 = NULL;
-	str = (_tmp9 = g_strconcat (str, (")"), NULL), str = (g_free (str), NULL), _tmp9);
+	str = (_tmp9 = g_strconcat (str, ")", NULL), str = (g_free (str), NULL), _tmp9);
 	return str;
 }
 
