@@ -24,6 +24,8 @@
 #include <gee/arraylist.h>
 #include <gee/collection.h>
 #include <vala/valasymbol.h>
+#include <vala/valatypesymbol.h>
+#include <vala/valacodenode.h>
 
 
 
@@ -95,7 +97,7 @@ static char* vala_delegate_type_real_to_qualified_string (ValaDataType* base, Va
 	if (vala_data_type_get_nullable ((ValaDataType*) self)) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		s = (_tmp0 = g_strconcat (s, ("?"), NULL), s = (g_free (s), NULL), _tmp0);
+		s = (_tmp0 = g_strconcat (s, "?", NULL), s = (g_free (s), NULL), _tmp0);
 	}
 	return s;
 }
