@@ -62,7 +62,7 @@ void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value);
 void vala_enum_add_method (ValaEnum* self, ValaMethod* m);
 GeeList* vala_enum_get_values (ValaEnum* self);
 GeeList* vala_enum_get_methods (ValaEnum* self);
-char* vala_enum_get_cprefix (ValaEnum* self);
+void vala_enum_set_cname (ValaEnum* self, const char* cname);
 void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix);
 void vala_enum_process_attributes (ValaEnum* self);
 void vala_enum_set_type_id (ValaEnum* self, const char* type_id);
