@@ -43,6 +43,7 @@ enum  {
 static void vala_error_code_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_error_code_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_error_code_real_get_cname (ValaTypeSymbol* base, gboolean const_type);
+static char* vala_error_code_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
 static gboolean vala_error_code_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_error_code_parent_class = NULL;
 static void vala_error_code_finalize (ValaCodeNode* obj);
@@ -130,6 +131,17 @@ static char* vala_error_code_real_get_cname (ValaTypeSymbol* base, gboolean cons
 }
 
 
+static char* vala_error_code_real_get_lower_case_cname (ValaSymbol* base, const char* infix) {
+	ValaErrorCode * self;
+	char* _tmp0;
+	char* _tmp1;
+	self = (ValaErrorCode*) base;
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_utf8_strdown (_tmp0 = vala_typesymbol_get_cname ((ValaTypeSymbol*) self, FALSE), -1), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+}
+
+
 static gboolean vala_error_code_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaErrorCode * self;
 	self = (ValaErrorCode*) base;
@@ -168,6 +180,7 @@ static void vala_error_code_class_init (ValaErrorCodeClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_error_code_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_error_code_real_accept_children;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_error_code_real_get_cname;
+	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_error_code_real_get_lower_case_cname;
 	VALA_CODE_NODE_CLASS (klass)->check = vala_error_code_real_check;
 }
 
