@@ -93,6 +93,8 @@ double vala_formal_parameter_get_carray_length_parameter_position (ValaFormalPar
 void vala_formal_parameter_set_carray_length_parameter_position (ValaFormalParameter* self, double value);
 double vala_formal_parameter_get_cdelegate_target_parameter_position (ValaFormalParameter* self);
 void vala_formal_parameter_set_cdelegate_target_parameter_position (ValaFormalParameter* self, double value);
+gboolean vala_formal_parameter_get_async_only (ValaFormalParameter* self);
+void vala_formal_parameter_set_async_only (ValaFormalParameter* self, gboolean value);
 const char* vala_formal_parameter_get_ctype (ValaFormalParameter* self);
 void vala_formal_parameter_set_ctype (ValaFormalParameter* self, const char* value);
 GType vala_formal_parameter_get_type (void);
