@@ -57,7 +57,6 @@ static void vala_local_variable_real_replace_type (ValaCodeNode* base, ValaDataT
 static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_local_variable_parent_class = NULL;
 static void vala_local_variable_finalize (ValaCodeNode* obj);
-static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
@@ -130,10 +129,10 @@ static void vala_local_variable_real_replace_type (ValaCodeNode* base, ValaDataT
 
 static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaLocalVariable * self;
-	ValaBlock* _tmp23;
-	ValaSymbol* _tmp22;
+	ValaBlock* _tmp22;
+	ValaSymbol* _tmp21;
 	ValaBlock* block;
-	gboolean _tmp24;
+	gboolean _tmp23;
 	self = (ValaLocalVariable*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -167,70 +166,55 @@ static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemantic
 		vala_data_type_set_floating_reference (vala_local_variable_get_variable_type (self), FALSE);
 		vala_expression_set_target_type (vala_local_variable_get_initializer (self), vala_local_variable_get_variable_type (self));
 	}
-	if (_vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) self), "result") == 0) {
-		gboolean _tmp4;
-		_tmp4 = FALSE;
-		if (analyzer->current_return_type == NULL) {
-			_tmp4 = TRUE;
-		} else {
-			_tmp4 = !vala_data_type_compatible (vala_local_variable_get_variable_type (self), analyzer->current_return_type);
-		}
-		/* warn if type of `result' variable is incompatible with return type
-		 as an implicit `result' variable might be introduced to be used
-		 by Vala postconditions and implicit checks generated by the code generated*/
-		if (_tmp4) {
-			vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), "result variable type incompatible with return type");
-		}
-	}
 	if (vala_local_variable_get_initializer (self) != NULL) {
 		if (vala_expression_get_value_type (vala_local_variable_get_initializer (self)) == NULL) {
-			gboolean _tmp5;
-			gboolean _tmp7;
-			_tmp5 = FALSE;
+			gboolean _tmp4;
+			gboolean _tmp6;
+			_tmp4 = FALSE;
 			if (!VALA_IS_MEMBER_ACCESS (vala_local_variable_get_initializer (self))) {
-				_tmp5 = !VALA_IS_LAMBDA_EXPRESSION (vala_local_variable_get_initializer (self));
+				_tmp4 = !VALA_IS_LAMBDA_EXPRESSION (vala_local_variable_get_initializer (self));
 			} else {
-				_tmp5 = FALSE;
+				_tmp4 = FALSE;
 			}
-			if (_tmp5) {
+			if (_tmp4) {
 				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "expression type not allowed as initializer");
 				return FALSE;
 			}
-			_tmp7 = FALSE;
+			_tmp6 = FALSE;
 			if (VALA_IS_METHOD (vala_expression_get_symbol_reference (vala_local_variable_get_initializer (self)))) {
-				_tmp7 = VALA_IS_DELEGATE_TYPE (vala_local_variable_get_variable_type (self));
+				_tmp6 = VALA_IS_DELEGATE_TYPE (vala_local_variable_get_variable_type (self));
 			} else {
-				_tmp7 = FALSE;
+				_tmp6 = FALSE;
 			}
-			if (_tmp7) {
-				ValaMethod* _tmp8;
+			if (_tmp6) {
+				ValaMethod* _tmp7;
 				ValaMethod* m;
-				ValaDelegateType* _tmp9;
+				ValaDelegateType* _tmp8;
 				ValaDelegateType* dt;
-				ValaDelegate* _tmp10;
+				ValaDelegate* _tmp9;
 				ValaDelegate* cb;
+				_tmp7 = NULL;
+				m = (_tmp7 = VALA_METHOD (vala_expression_get_symbol_reference (vala_local_variable_get_initializer (self))), (_tmp7 == NULL) ? NULL : vala_code_node_ref (_tmp7));
 				_tmp8 = NULL;
-				m = (_tmp8 = VALA_METHOD (vala_expression_get_symbol_reference (vala_local_variable_get_initializer (self))), (_tmp8 == NULL) ? NULL : vala_code_node_ref (_tmp8));
+				dt = (_tmp8 = VALA_DELEGATE_TYPE (vala_local_variable_get_variable_type (self)), (_tmp8 == NULL) ? NULL : vala_code_node_ref (_tmp8));
 				_tmp9 = NULL;
-				dt = (_tmp9 = VALA_DELEGATE_TYPE (vala_local_variable_get_variable_type (self)), (_tmp9 == NULL) ? NULL : vala_code_node_ref (_tmp9));
-				_tmp10 = NULL;
-				cb = (_tmp10 = vala_delegate_type_get_delegate_symbol (dt), (_tmp10 == NULL) ? NULL : vala_code_node_ref (_tmp10));
+				cb = (_tmp9 = vala_delegate_type_get_delegate_symbol (dt), (_tmp9 == NULL) ? NULL : vala_code_node_ref (_tmp9));
 				/* check whether method matches callback type */
 				if (!vala_delegate_matches_method (cb, m)) {
-					char* _tmp13;
 					char* _tmp12;
 					char* _tmp11;
-					gboolean _tmp14;
+					char* _tmp10;
+					gboolean _tmp13;
 					vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-					_tmp13 = NULL;
 					_tmp12 = NULL;
 					_tmp11 = NULL;
-					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp13 = g_strdup_printf ("declaration of method `%s' doesn't match declaration of callback `%s'", _tmp11 = vala_symbol_get_full_name ((ValaSymbol*) m), _tmp12 = vala_symbol_get_full_name ((ValaSymbol*) cb)));
-					_tmp13 = (g_free (_tmp13), NULL);
+					_tmp10 = NULL;
+					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp12 = g_strdup_printf ("declaration of method `%s' doesn't match declaration of callback `%s'", _tmp10 = vala_symbol_get_full_name ((ValaSymbol*) m), _tmp11 = vala_symbol_get_full_name ((ValaSymbol*) cb)));
 					_tmp12 = (g_free (_tmp12), NULL);
 					_tmp11 = (g_free (_tmp11), NULL);
-					return (_tmp14 = FALSE, (m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL)), (dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL)), (cb == NULL) ? NULL : (cb = (vala_code_node_unref (cb), NULL)), _tmp14);
+					_tmp10 = (g_free (_tmp10), NULL);
+					return (_tmp13 = FALSE, (m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL)), (dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL)), (cb == NULL) ? NULL : (cb = (vala_code_node_unref (cb), NULL)), _tmp13);
 				}
 				vala_expression_set_value_type (vala_local_variable_get_initializer (self), vala_local_variable_get_variable_type (self));
 				(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
@@ -243,29 +227,29 @@ static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemantic
 			}
 		}
 		if (!vala_data_type_compatible (vala_expression_get_value_type (vala_local_variable_get_initializer (self)), vala_local_variable_get_variable_type (self))) {
-			char* _tmp18;
 			char* _tmp17;
 			char* _tmp16;
+			char* _tmp15;
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			_tmp18 = NULL;
 			_tmp17 = NULL;
 			_tmp16 = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp18 = g_strdup_printf ("Assignment: Cannot convert from `%s' to `%s'", _tmp16 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_local_variable_get_initializer (self))), _tmp17 = vala_code_node_to_string ((ValaCodeNode*) vala_local_variable_get_variable_type (self))));
-			_tmp18 = (g_free (_tmp18), NULL);
+			_tmp15 = NULL;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp17 = g_strdup_printf ("Assignment: Cannot convert from `%s' to `%s'", _tmp15 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_local_variable_get_initializer (self))), _tmp16 = vala_code_node_to_string ((ValaCodeNode*) vala_local_variable_get_variable_type (self))));
 			_tmp17 = (g_free (_tmp17), NULL);
 			_tmp16 = (g_free (_tmp16), NULL);
+			_tmp15 = (g_free (_tmp15), NULL);
 			return FALSE;
 		}
 		if (vala_data_type_is_disposable (vala_expression_get_value_type (vala_local_variable_get_initializer (self)))) {
-			gboolean _tmp20;
-			_tmp20 = FALSE;
+			gboolean _tmp19;
+			_tmp19 = FALSE;
 			if (!VALA_IS_POINTER_TYPE (vala_local_variable_get_variable_type (self))) {
-				_tmp20 = !vala_data_type_get_value_owned (vala_local_variable_get_variable_type (self));
+				_tmp19 = !vala_data_type_get_value_owned (vala_local_variable_get_variable_type (self));
 			} else {
-				_tmp20 = FALSE;
+				_tmp19 = FALSE;
 			}
 			/* rhs transfers ownership of the expression */
-			if (_tmp20) {
+			if (_tmp19) {
 				/* lhs doesn't own the value */
 				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Invalid assignment from owned expression to unowned variable");
@@ -277,14 +261,14 @@ static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemantic
 	vala_scope_add (vala_symbol_get_scope (vala_semantic_analyzer_get_current_symbol (analyzer)), vala_symbol_get_name ((ValaSymbol*) self), (ValaSymbol*) self);
 	/* current_symbol is a Method if this is the `result'
 	 variable used for postconditions*/
-	_tmp23 = NULL;
 	_tmp22 = NULL;
-	block = (_tmp23 = (_tmp22 = vala_semantic_analyzer_get_current_symbol (analyzer), VALA_IS_BLOCK (_tmp22) ? ((ValaBlock*) _tmp22) : NULL), (_tmp23 == NULL) ? NULL : vala_code_node_ref (_tmp23));
+	_tmp21 = NULL;
+	block = (_tmp22 = (_tmp21 = vala_semantic_analyzer_get_current_symbol (analyzer), VALA_IS_BLOCK (_tmp21) ? ((ValaBlock*) _tmp21) : NULL), (_tmp22 == NULL) ? NULL : vala_code_node_ref (_tmp22));
 	if (block != NULL) {
 		vala_block_add_local_variable (block, self);
 	}
 	vala_symbol_set_active ((ValaSymbol*) self, TRUE);
-	return (_tmp24 = !vala_code_node_get_error ((ValaCodeNode*) self), (block == NULL) ? NULL : (block = (vala_code_node_unref (block), NULL)), _tmp24);
+	return (_tmp23 = !vala_code_node_get_error ((ValaCodeNode*) self), (block == NULL) ? NULL : (block = (vala_code_node_unref (block), NULL)), _tmp23);
 }
 
 
@@ -374,16 +358,5 @@ GType vala_local_variable_get_type (void) {
 }
 
 
-static int _vala_strcmp0 (const char * str1, const char * str2) {
-	if (str1 == NULL) {
-		return -(str1 != str2);
-	}
-	if (str2 == NULL) {
-		return str1 != str2;
-	}
-	return strcmp (str1, str2);
-}
-
-
 
 
