@@ -1,6 +1,7 @@
 /* valamethod.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2009  Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -116,10 +117,14 @@ double vala_method_get_cdelegate_target_parameter_position (ValaMethod* self);
 void vala_method_set_cdelegate_target_parameter_position (ValaMethod* self, double value);
 gboolean vala_method_get_no_array_length (ValaMethod* self);
 void vala_method_set_no_array_length (ValaMethod* self, gboolean value);
+gboolean vala_method_get_array_null_terminated (ValaMethod* self);
+void vala_method_set_array_null_terminated (ValaMethod* self, gboolean value);
 gboolean vala_method_get_printf_format (ValaMethod* self);
 void vala_method_set_printf_format (ValaMethod* self, gboolean value);
 gboolean vala_method_get_has_construct_function (ValaMethod* self);
 void vala_method_set_has_construct_function (ValaMethod* self, gboolean value);
+ValaSignal* vala_method_get_signal_reference (ValaMethod* self);
+void vala_method_set_signal_reference (ValaMethod* self, ValaSignal* value);
 gboolean vala_method_get_coroutine (ValaMethod* self);
 void vala_method_set_coroutine (ValaMethod* self, gboolean value);
 GType vala_method_get_type (void);
