@@ -299,12 +299,12 @@ static gboolean vala_method_call_real_check (ValaCodeNode* base, ValaSemanticAna
 		} else {
 			_tmp14 = FALSE;
 		}
-		if ((_tmp14)) {
+		if (_tmp14) {
 			_tmp13 = TRUE;
 		} else {
 			_tmp13 = VALA_IS_STRUCT (vala_expression_get_symbol_reference (vala_method_call_get_call (self)));
 		}
-		_tmp12 = (_tmp13);
+		_tmp12 = _tmp13;
 	} else {
 		_tmp12 = FALSE;
 	}
@@ -441,7 +441,7 @@ static gboolean vala_method_call_real_check (ValaCodeNode* base, ValaSemanticAna
 	}
 	_tmp30 = FALSE;
 	if (VALA_IS_METHOD_TYPE (mtype)) {
-		_tmp30 = vala_method_get_printf_format (vala_method_type_get_method_symbol ((VALA_METHOD_TYPE (mtype))));
+		_tmp30 = vala_method_get_printf_format (vala_method_type_get_method_symbol (VALA_METHOD_TYPE (mtype)));
 	} else {
 		_tmp30 = FALSE;
 	}
@@ -852,13 +852,13 @@ static gboolean vala_method_call_real_check (ValaCodeNode* base, ValaSemanticAna
 		gboolean _tmp90;
 		_tmp89 = FALSE;
 		_tmp90 = FALSE;
-		if (!(VALA_IS_EXPRESSION_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) self)))) {
-			_tmp90 = !(VALA_IS_FOR_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) self)));
+		if (!VALA_IS_EXPRESSION_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) self))) {
+			_tmp90 = !VALA_IS_FOR_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) self));
 		} else {
 			_tmp90 = FALSE;
 		}
 		if (_tmp90) {
-			_tmp89 = !(VALA_IS_YIELD_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) self)));
+			_tmp89 = !VALA_IS_YIELD_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) self));
 		} else {
 			_tmp89 = FALSE;
 		}
@@ -881,7 +881,7 @@ static gboolean vala_method_call_real_check (ValaCodeNode* base, ValaSemanticAna
 		ValaMethod* _tmp93;
 		ValaMethod* m;
 		_tmp93 = NULL;
-		m = (_tmp93 = vala_method_type_get_method_symbol ((VALA_METHOD_TYPE (mtype))), (_tmp93 == NULL) ? NULL : vala_code_node_ref (_tmp93));
+		m = (_tmp93 = vala_method_type_get_method_symbol (VALA_METHOD_TYPE (mtype)), (_tmp93 == NULL) ? NULL : vala_code_node_ref (_tmp93));
 		{
 			GeeList* _tmp94;
 			GeeIterator* _tmp95;
@@ -909,7 +909,7 @@ static gboolean vala_method_call_real_check (ValaCodeNode* base, ValaSemanticAna
 			ValaDelegate* _tmp96;
 			ValaDelegate* d;
 			_tmp96 = NULL;
-			d = (_tmp96 = vala_delegate_type_get_delegate_symbol ((VALA_DELEGATE_TYPE (mtype))), (_tmp96 == NULL) ? NULL : vala_code_node_ref (_tmp96));
+			d = (_tmp96 = vala_delegate_type_get_delegate_symbol (VALA_DELEGATE_TYPE (mtype)), (_tmp96 == NULL) ? NULL : vala_code_node_ref (_tmp96));
 			{
 				GeeList* _tmp97;
 				GeeIterator* _tmp98;
