@@ -1,6 +1,6 @@
 /* valanamespace.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -40,8 +40,6 @@
 #include <vala/valafield.h>
 #include <vala/valamethod.h>
 #include <vala/valascope.h>
-#include <vala/valadatatype.h>
-#include <vala/valasourcefile.h>
 #include <vala/valamember.h>
 #include <vala/valareport.h>
 #include <vala/valacreationmethod.h>
@@ -225,7 +223,7 @@ void vala_namespace_add_namespace (ValaNamespace* self, ValaNamespace* ns) {
 			GeeIterator* _ed_it;
 			_tmp15 = NULL;
 			_tmp16 = NULL;
-			_ed_it = (_tmp16 = gee_iterable_iterator ((GeeIterable*) (_tmp15 = vala_namespace_get_error_types (ns))), (_tmp15 == NULL) ? NULL : (_tmp15 = (gee_collection_object_unref (_tmp15), NULL)), _tmp16);
+			_ed_it = (_tmp16 = gee_iterable_iterator ((GeeIterable*) (_tmp15 = vala_namespace_get_error_domains (ns))), (_tmp15 == NULL) ? NULL : (_tmp15 = (gee_collection_object_unref (_tmp15), NULL)), _tmp16);
 			while (gee_iterator_next (_ed_it)) {
 				ValaErrorDomain* ed;
 				ed = (ValaErrorDomain*) gee_iterator_get (_ed_it);
@@ -304,81 +302,14 @@ GeeList* vala_namespace_get_namespaces (ValaNamespace* self) {
  * @param cl a class
  */
 void vala_namespace_add_class (ValaNamespace* self, ValaClass* cl) {
-	ValaSymbol* _tmp0;
-	gboolean _tmp1;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (cl != NULL);
-	_tmp0 = NULL;
-	if ((_tmp1 = VALA_IS_CLASS (_tmp0 = vala_scope_lookup (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) cl))), (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-		ValaClass* old_class;
-		/* merge*/
-		old_class = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) cl)));
-		{
-			GeeList* _tmp2;
-			GeeIterator* _tmp3;
-			GeeIterator* _base_type_it;
-			_tmp2 = NULL;
-			_tmp3 = NULL;
-			_base_type_it = (_tmp3 = gee_iterable_iterator ((GeeIterable*) (_tmp2 = vala_class_get_base_types (cl))), (_tmp2 == NULL) ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)), _tmp3);
-			while (gee_iterator_next (_base_type_it)) {
-				ValaDataType* base_type;
-				base_type = (ValaDataType*) gee_iterator_get (_base_type_it);
-				vala_class_add_base_type (old_class, base_type);
-				(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
-			}
-			(_base_type_it == NULL) ? NULL : (_base_type_it = (gee_collection_object_unref (_base_type_it), NULL));
-		}
-		{
-			GeeList* _tmp4;
-			GeeIterator* _tmp5;
-			GeeIterator* _f_it;
-			_tmp4 = NULL;
-			_tmp5 = NULL;
-			_f_it = (_tmp5 = gee_iterable_iterator ((GeeIterable*) (_tmp4 = vala_class_get_fields (cl))), (_tmp4 == NULL) ? NULL : (_tmp4 = (gee_collection_object_unref (_tmp4), NULL)), _tmp5);
-			while (gee_iterator_next (_f_it)) {
-				ValaField* f;
-				f = (ValaField*) gee_iterator_get (_f_it);
-				vala_class_add_field (old_class, f);
-				(f == NULL) ? NULL : (f = (vala_code_node_unref (f), NULL));
-			}
-			(_f_it == NULL) ? NULL : (_f_it = (gee_collection_object_unref (_f_it), NULL));
-		}
-		{
-			GeeList* _tmp6;
-			GeeIterator* _tmp7;
-			GeeIterator* _m_it;
-			_tmp6 = NULL;
-			_tmp7 = NULL;
-			_m_it = (_tmp7 = gee_iterable_iterator ((GeeIterable*) (_tmp6 = vala_object_type_symbol_get_methods ((ValaObjectTypeSymbol*) cl))), (_tmp6 == NULL) ? NULL : (_tmp6 = (gee_collection_object_unref (_tmp6), NULL)), _tmp7);
-			while (gee_iterator_next (_m_it)) {
-				ValaMethod* m;
-				gboolean _tmp8;
-				m = (ValaMethod*) gee_iterator_get (_m_it);
-				_tmp8 = FALSE;
-				if (m == vala_class_get_default_construction_method (cl)) {
-					_tmp8 = vala_class_get_default_construction_method (old_class) != NULL;
-				} else {
-					_tmp8 = FALSE;
-				}
-				if (_tmp8) {
-					/* ignore secondary default creation method*/
-					(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
-					continue;
-				}
-				vala_class_add_method (old_class, m);
-				(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
-			}
-			(_m_it == NULL) ? NULL : (_m_it = (gee_collection_object_unref (_m_it), NULL));
-		}
-		if (vala_class_get_constructor (cl) != NULL) {
-			vala_class_set_constructor (old_class, vala_class_get_constructor (cl));
-		}
-		vala_source_file_remove_node (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) cl)), (ValaCodeNode*) cl);
-		(old_class == NULL) ? NULL : (old_class = (vala_code_node_unref (old_class), NULL));
-	} else {
-		gee_collection_add ((GeeCollection*) self->priv->classes, cl);
-		vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) cl), (ValaSymbol*) cl);
+	/* namespaces do not support private memebers*/
+	if (vala_symbol_get_access ((ValaSymbol*) cl) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		vala_symbol_set_access ((ValaSymbol*) cl, VALA_SYMBOL_ACCESSIBILITY_INTERNAL);
 	}
+	gee_collection_add ((GeeCollection*) self->priv->classes, cl);
+	vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) cl), (ValaSymbol*) cl);
 }
 
 
@@ -390,6 +321,10 @@ void vala_namespace_add_class (ValaNamespace* self, ValaClass* cl) {
 void vala_namespace_add_interface (ValaNamespace* self, ValaInterface* iface) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (iface != NULL);
+	/* namespaces do not support private memebers*/
+	if (vala_symbol_get_access ((ValaSymbol*) iface) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		vala_symbol_set_access ((ValaSymbol*) iface, VALA_SYMBOL_ACCESSIBILITY_INTERNAL);
+	}
 	gee_collection_add ((GeeCollection*) self->priv->interfaces, iface);
 	vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) iface), (ValaSymbol*) iface);
 }
@@ -403,6 +338,10 @@ void vala_namespace_add_interface (ValaNamespace* self, ValaInterface* iface) {
 void vala_namespace_add_struct (ValaNamespace* self, ValaStruct* st) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (st != NULL);
+	/* namespaces do not support private memebers*/
+	if (vala_symbol_get_access ((ValaSymbol*) st) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		vala_symbol_set_access ((ValaSymbol*) st, VALA_SYMBOL_ACCESSIBILITY_INTERNAL);
+	}
 	gee_collection_add ((GeeCollection*) self->priv->structs, st);
 	vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) st), (ValaSymbol*) st);
 }
@@ -429,6 +368,10 @@ void vala_namespace_remove_struct (ValaNamespace* self, ValaStruct* st) {
 void vala_namespace_add_enum (ValaNamespace* self, ValaEnum* en) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (en != NULL);
+	/* namespaces do not support private memebers*/
+	if (vala_symbol_get_access ((ValaSymbol*) en) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		vala_symbol_set_access ((ValaSymbol*) en, VALA_SYMBOL_ACCESSIBILITY_INTERNAL);
+	}
 	gee_collection_add ((GeeCollection*) self->priv->enums, en);
 	vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) en), (ValaSymbol*) en);
 }
@@ -442,6 +385,10 @@ void vala_namespace_add_enum (ValaNamespace* self, ValaEnum* en) {
 void vala_namespace_add_error_domain (ValaNamespace* self, ValaErrorDomain* edomain) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (edomain != NULL);
+	/* namespaces do not support private memebers*/
+	if (vala_symbol_get_access ((ValaSymbol*) edomain) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		vala_symbol_set_access ((ValaSymbol*) edomain, VALA_SYMBOL_ACCESSIBILITY_INTERNAL);
+	}
 	gee_collection_add ((GeeCollection*) self->priv->error_domains, edomain);
 	vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) edomain), (ValaSymbol*) edomain);
 }
@@ -455,6 +402,10 @@ void vala_namespace_add_error_domain (ValaNamespace* self, ValaErrorDomain* edom
 void vala_namespace_add_delegate (ValaNamespace* self, ValaDelegate* d) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (d != NULL);
+	/* namespaces do not support private memebers*/
+	if (vala_symbol_get_access ((ValaSymbol*) d) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		vala_symbol_set_access ((ValaSymbol*) d, VALA_SYMBOL_ACCESSIBILITY_INTERNAL);
+	}
 	gee_collection_add ((GeeCollection*) self->priv->delegates, d);
 	vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) d), (ValaSymbol*) d);
 }
@@ -509,7 +460,7 @@ GeeList* vala_namespace_get_enums (ValaNamespace* self) {
  *
  * @return error domain list
  */
-GeeList* vala_namespace_get_error_types (ValaNamespace* self) {
+GeeList* vala_namespace_get_error_domains (ValaNamespace* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return (GeeList*) gee_read_only_list_new (VALA_TYPE_ERROR_DOMAIN, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->error_domains);
 }
@@ -567,6 +518,10 @@ GeeList* vala_namespace_get_methods (ValaNamespace* self) {
 void vala_namespace_add_constant (ValaNamespace* self, ValaConstant* constant) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (constant != NULL);
+	/* namespaces do not support private memebers*/
+	if (vala_symbol_get_access ((ValaSymbol*) constant) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		vala_symbol_set_access ((ValaSymbol*) constant, VALA_SYMBOL_ACCESSIBILITY_INTERNAL);
+	}
 	gee_collection_add ((GeeCollection*) self->priv->constants, constant);
 	vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), vala_symbol_get_name ((ValaSymbol*) constant), (ValaSymbol*) constant);
 }
@@ -580,6 +535,10 @@ void vala_namespace_add_constant (ValaNamespace* self, ValaConstant* constant) {
 void vala_namespace_add_field (ValaNamespace* self, ValaField* f) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (f != NULL);
+	/* namespaces do not support private memebers*/
+	if (vala_symbol_get_access ((ValaSymbol*) f) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		vala_symbol_set_access ((ValaSymbol*) f, VALA_SYMBOL_ACCESSIBILITY_INTERNAL);
+	}
 	if (vala_field_get_binding (f) == MEMBER_BINDING_INSTANCE) {
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) f), "instance members are not allowed outside of data types");
 		vala_code_node_set_error ((ValaCodeNode*) f, TRUE);
@@ -604,6 +563,10 @@ void vala_namespace_add_field (ValaNamespace* self, ValaField* f) {
 void vala_namespace_add_method (ValaNamespace* self, ValaMethod* m) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (m != NULL);
+	/* namespaces do not support private memebers*/
+	if (vala_symbol_get_access ((ValaSymbol*) m) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		vala_symbol_set_access ((ValaSymbol*) m, VALA_SYMBOL_ACCESSIBILITY_INTERNAL);
+	}
 	if (VALA_IS_CREATION_METHOD (m)) {
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) m), "construction methods may only be declared within classes and structs");
 		vala_code_node_set_error ((ValaCodeNode*) m, TRUE);
@@ -934,6 +897,18 @@ void vala_namespace_set_cheader_filename (ValaNamespace* self, const char* chead
 }
 
 
+/**
+ * Adds a C header filename of this namespace.
+ *
+ * @param cheader_filename header filename
+ */
+void vala_namespace_add_cheader_filename (ValaNamespace* self, const char* cheader_filename) {
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (cheader_filename != NULL);
+	gee_collection_add ((GeeCollection*) self->priv->cheader_filenames, cheader_filename);
+}
+
+
 static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAttribute* a) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (a != NULL);
