@@ -1,6 +1,6 @@
 /* valapropertyaccessor.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,8 +27,8 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
+#include <vala/valasymbol.h>
 
 G_BEGIN_DECLS
 
@@ -56,11 +56,13 @@ struct _ValaPropertyAccessorClass {
 
 
 char* vala_property_accessor_get_cname (ValaPropertyAccessor* self);
-ValaPropertyAccessor* vala_property_accessor_construct (GType object_type, gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference);
-ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference);
+ValaPropertyAccessor* vala_property_accessor_construct (GType object_type, gboolean readable, gboolean writable, gboolean construction, ValaDataType* value_type, ValaBlock* body, ValaSourceReference* source_reference);
+ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaDataType* value_type, ValaBlock* body, ValaSourceReference* source_reference);
 void vala_property_accessor_process_attributes (ValaPropertyAccessor* self);
 ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self);
 void vala_property_accessor_set_prop (ValaPropertyAccessor* self, ValaProperty* value);
+ValaDataType* vala_property_accessor_get_value_type (ValaPropertyAccessor* self);
+void vala_property_accessor_set_value_type (ValaPropertyAccessor* self, ValaDataType* value);
 gboolean vala_property_accessor_get_readable (ValaPropertyAccessor* self);
 void vala_property_accessor_set_readable (ValaPropertyAccessor* self, gboolean value);
 gboolean vala_property_accessor_get_writable (ValaPropertyAccessor* self);
