@@ -112,10 +112,14 @@ static gboolean vala_return_statement_real_check (ValaCodeNode* base, ValaSemant
 	ValaReturnStatement * self;
 	gboolean _tmp1;
 	gboolean _tmp11;
-	gboolean _tmp13;
-	gboolean _tmp14;
+	ValaLocalVariable* _tmp14;
+	ValaSymbol* _tmp13;
+	ValaLocalVariable* local;
 	gboolean _tmp15;
-	GeeList* _tmp18;
+	gboolean _tmp16;
+	gboolean _tmp18;
+	GeeList* _tmp21;
+	gboolean _tmp22;
 	self = (ValaReturnStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -142,7 +146,7 @@ static gboolean vala_return_statement_real_check (ValaCodeNode* base, ValaSemant
 		return FALSE;
 	}
 	if (vala_return_statement_get_return_expression (self) == NULL) {
-		if (!(VALA_IS_VOID_TYPE (analyzer->current_return_type))) {
+		if (!VALA_IS_VOID_TYPE (analyzer->current_return_type)) {
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Return without value in non-void function");
 		}
@@ -182,40 +186,46 @@ static gboolean vala_return_statement_real_check (ValaCodeNode* base, ValaSemant
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Return value transfers ownership but method return type hasn't been declared to transfer ownership");
 		return FALSE;
 	}
-	_tmp13 = FALSE;
-	_tmp14 = FALSE;
-	if (VALA_IS_LOCAL_VARIABLE (vala_expression_get_symbol_reference (vala_return_statement_get_return_expression (self)))) {
-		_tmp14 = vala_data_type_is_disposable (vala_expression_get_value_type (vala_return_statement_get_return_expression (self)));
-	} else {
-		_tmp14 = FALSE;
-	}
-	if (_tmp14) {
-		_tmp13 = !vala_data_type_get_value_owned (analyzer->current_return_type);
-	} else {
-		_tmp13 = FALSE;
-	}
-	if (_tmp13) {
-		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Local variable with strong reference used as return value and method return type hasn't been declared to transfer ownership");
-	}
+	_tmp14 = NULL;
+	_tmp13 = NULL;
+	local = (_tmp14 = (_tmp13 = vala_expression_get_symbol_reference (vala_return_statement_get_return_expression (self)), VALA_IS_LOCAL_VARIABLE (_tmp13) ? ((ValaLocalVariable*) _tmp13) : NULL), (_tmp14 == NULL) ? NULL : vala_code_node_ref (_tmp14));
 	_tmp15 = FALSE;
-	if (VALA_IS_NULL_LITERAL (vala_return_statement_get_return_expression (self))) {
-		_tmp15 = !vala_data_type_get_nullable (analyzer->current_return_type);
+	_tmp16 = FALSE;
+	if (local != NULL) {
+		_tmp16 = vala_data_type_is_disposable (vala_local_variable_get_variable_type (local));
+	} else {
+		_tmp16 = FALSE;
+	}
+	if (_tmp16) {
+		_tmp15 = !vala_data_type_get_value_owned (analyzer->current_return_type);
 	} else {
 		_tmp15 = FALSE;
 	}
 	if (_tmp15) {
-		char* _tmp17;
-		char* _tmp16;
-		_tmp17 = NULL;
-		_tmp16 = NULL;
-		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp17 = g_strdup_printf ("`null' incompatible with return type `%s`", _tmp16 = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
-		_tmp17 = (g_free (_tmp17), NULL);
-		_tmp16 = (g_free (_tmp16), NULL);
+		gboolean _tmp17;
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Local variable with strong reference used as return value and method return type has not been declared to transfer ownership");
+		return (_tmp17 = FALSE, (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp17);
 	}
-	_tmp18 = NULL;
-	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp18 = vala_code_node_get_error_types ((ValaCodeNode*) vala_return_statement_get_return_expression (self)));
-	(_tmp18 == NULL) ? NULL : (_tmp18 = (gee_collection_object_unref (_tmp18), NULL));
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	_tmp18 = FALSE;
+	if (VALA_IS_NULL_LITERAL (vala_return_statement_get_return_expression (self))) {
+		_tmp18 = !vala_data_type_get_nullable (analyzer->current_return_type);
+	} else {
+		_tmp18 = FALSE;
+	}
+	if (_tmp18) {
+		char* _tmp20;
+		char* _tmp19;
+		_tmp20 = NULL;
+		_tmp19 = NULL;
+		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp20 = g_strdup_printf ("`null' incompatible with return type `%s`", _tmp19 = vala_code_node_to_string ((ValaCodeNode*) analyzer->current_return_type)));
+		_tmp20 = (g_free (_tmp20), NULL);
+		_tmp19 = (g_free (_tmp19), NULL);
+	}
+	_tmp21 = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp21 = vala_code_node_get_error_types ((ValaCodeNode*) vala_return_statement_get_return_expression (self)));
+	(_tmp21 == NULL) ? NULL : (_tmp21 = (gee_collection_object_unref (_tmp21), NULL));
+	return (_tmp22 = !vala_code_node_get_error ((ValaCodeNode*) self), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp22);
 }
 
 
