@@ -73,13 +73,10 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
-	ValaTypeSymbol* initially_unowned_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
 	ValaClass* gerror_type;
-	ValaInterface* list_type;
-	ValaInterface* map_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
 };
