@@ -1,6 +1,6 @@
 /* valasignal.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -311,8 +311,10 @@ ValaMethod* vala_signal_get_method_handler (ValaSignal* self) {
 		ValaMethod* _tmp0;
 		_tmp0 = NULL;
 		self->priv->generated_method = (_tmp0 = vala_method_new (vala_symbol_get_name ((ValaSymbol*) self), vala_signal_get_return_type (self), vala_code_node_get_source_reference ((ValaCodeNode*) self)), (self->priv->generated_method == NULL) ? NULL : (self->priv->generated_method = (vala_code_node_unref (self->priv->generated_method), NULL)), _tmp0);
+		vala_symbol_set_access ((ValaSymbol*) self->priv->generated_method, vala_symbol_get_access ((ValaSymbol*) self));
 		vala_method_set_is_virtual (self->priv->generated_method, TRUE);
 		vala_method_set_vfunc_name (self->priv->generated_method, vala_symbol_get_name ((ValaSymbol*) self));
+		vala_method_set_signal_reference (self->priv->generated_method, self);
 		{
 			GeeIterator* _param_it;
 			_param_it = gee_iterable_iterator ((GeeIterable*) self->priv->parameters);
