@@ -114,7 +114,7 @@ char* vala_source_reference_to_string (ValaSourceReference* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = (g_strdup_printf ("%s:%d.%d-%d.%d", _tmp0 = vala_source_file_get_relative_filename (self->priv->_file), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%s:%d.%d-%d.%d", _tmp0 = vala_source_file_get_relative_filename (self->priv->_file), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 }
 
 
