@@ -25,9 +25,9 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/list.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/list.h>
 #include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
 
@@ -66,6 +66,7 @@ GeeList* vala_struct_get_fields (ValaStruct* self);
 GeeList* vala_struct_get_constants (ValaStruct* self);
 void vala_struct_add_method (ValaStruct* self, ValaMethod* m);
 GeeList* vala_struct_get_methods (ValaStruct* self);
+void vala_struct_set_cname (ValaStruct* self, const char* cname);
 char* vala_struct_get_default_cname (ValaStruct* self);
 gboolean vala_struct_is_boolean_type (ValaStruct* self);
 gboolean vala_struct_is_integer_type (ValaStruct* self);
@@ -73,8 +74,6 @@ gboolean vala_struct_is_floating_type (ValaStruct* self);
 gint vala_struct_get_rank (ValaStruct* self);
 void vala_struct_process_attributes (ValaStruct* self);
 void vala_struct_set_type_id (ValaStruct* self, const char* name);
-void vala_struct_add_base_type (ValaStruct* self, ValaDataType* type);
-GeeList* vala_struct_get_base_types (ValaStruct* self);
 gboolean vala_struct_is_simple_type (ValaStruct* self);
 void vala_struct_set_simple_type (ValaStruct* self, gboolean simple_type);
 char* vala_struct_get_default_copy_function (ValaStruct* self);
@@ -82,8 +81,13 @@ void vala_struct_set_copy_function (ValaStruct* self, const char* name);
 char* vala_struct_get_default_destroy_function (ValaStruct* self);
 void vala_struct_set_destroy_function (ValaStruct* self, const char* name);
 gboolean vala_struct_is_disposable (ValaStruct* self);
+ValaDataType* vala_struct_get_base_type (ValaStruct* self);
+void vala_struct_set_base_type (ValaStruct* self, ValaDataType* value);
+ValaStruct* vala_struct_get_base_struct (ValaStruct* self);
 ValaMethod* vala_struct_get_default_construction_method (ValaStruct* self);
 void vala_struct_set_default_construction_method (ValaStruct* self, ValaMethod* value);
+gboolean vala_struct_get_use_const (ValaStruct* self);
+void vala_struct_set_use_const (ValaStruct* self, gboolean value);
 gboolean vala_struct_get_has_type_id (ValaStruct* self);
 void vala_struct_set_has_type_id (ValaStruct* self, gboolean value);
 GType vala_struct_get_type (void);
