@@ -21,8 +21,8 @@
  */
 
 #include <vala/valatypeparameter.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valasourcereference.h>
+#include <vala/valacodevisitor.h>
 
 
 
@@ -47,8 +47,7 @@ ValaTypeParameter* vala_typeparameter_construct (GType object_type, const char*
 	ValaTypeParameter* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference != NULL, NULL);
-	self = ((ValaTypeParameter*) (g_type_create_instance (object_type)));
-	self = ((ValaTypeParameter*) (vala_symbol_construct (object_type, name, source_reference)));
+	self = (ValaTypeParameter*) vala_symbol_construct (object_type, name, source_reference);
 	return self;
 }
 
@@ -60,7 +59,7 @@ ValaTypeParameter* vala_typeparameter_new (const char* name, ValaSourceReference
 
 static void vala_typeparameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaTypeParameter * self;
-	self = ((ValaTypeParameter*) (base));
+	self = (ValaTypeParameter*) base;
 	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_type_parameter (visitor, self);
 }
