@@ -121,9 +121,9 @@ static char* vala_markup_reader_read_name (ValaMarkupReader* self) {
 		if (_tmp0) {
 			break;
 		}
-		u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+		u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 		if (u != ((gunichar) (-1))) {
-			self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
+			self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
 		} else {
 			vala_report_error (NULL, "invalid UTF-8 character");
 		}
@@ -131,7 +131,7 @@ static char* vala_markup_reader_read_name (ValaMarkupReader* self) {
 	if (self->priv->current == begin) {
 	}
 	/* syntax error: invalid name*/
-	return g_strndup (((const char*) begin), self->priv->current - begin);
+	return g_strndup ((const char*) begin, self->priv->current - begin);
 }
 
 
@@ -178,7 +178,7 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 						}
 						if (_tmp1) {
 							/* comment*/
-							self->priv->current = self->priv->current + (2);
+							self->priv->current = self->priv->current + 2;
 							while (self->priv->current < (self->priv->end - 2)) {
 								gboolean _tmp3;
 								gboolean _tmp4;
@@ -196,7 +196,7 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 								}
 								if (_tmp3) {
 									/* end of comment*/
-									self->priv->current = self->priv->current + (3);
+									self->priv->current = self->priv->current + 3;
 									break;
 								}
 								self->priv->current++;
@@ -290,15 +290,15 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 									if (!_tmp13) {
 										break;
 									}
-									u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+									u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 									if (u != ((gunichar) (-1))) {
-										self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
+										self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
 									} else {
 										vala_report_error (NULL, "invalid UTF-8 character");
 									}
 								}
 								/* TODO process &amp; &gt; &lt; &quot; &apos;*/
-								attr_value = g_strndup (((const char*) attr_begin), self->priv->current - attr_begin);
+								attr_value = g_strndup ((const char*) attr_begin, self->priv->current - attr_begin);
 								_tmp14 = FALSE;
 								if (self->priv->current >= self->priv->end) {
 									_tmp14 = TRUE;
@@ -351,9 +351,9 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 				if (!_tmp16) {
 					break;
 				}
-				u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+				u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 				if (u != ((gunichar) (-1))) {
-					self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
+					self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
 				} else {
 					vala_report_error (NULL, "invalid UTF-8 character");
 				}
