@@ -192,7 +192,8 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	ValaGIdlParser* gidlparser;
 	ValaSymbolResolver* resolver;
 	ValaSemanticAnalyzer* analyzer;
-	gint _tmp26;
+	gboolean _tmp22;
+	gint _tmp29;
 	g_return_val_if_fail (self != NULL, 0);
 	_tmp0 = NULL;
 	self->priv->context = (_tmp0 = vala_code_context_new (), (self->priv->context == NULL) ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL)), _tmp0);
@@ -362,19 +363,32 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		gint _tmp21;
 		return (_tmp21 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), (analyzer == NULL) ? NULL : (analyzer = (vala_code_visitor_unref (analyzer), NULL)), _tmp21);
 	}
+	_tmp22 = FALSE;
+	if (vala_vapi_gen_library == NULL) {
+		_tmp22 = vala_gir_parser_get_package_name (girparser) != NULL;
+	} else {
+		_tmp22 = FALSE;
+	}
+	if (_tmp22) {
+		char* _tmp24;
+		const char* _tmp23;
+		_tmp24 = NULL;
+		_tmp23 = NULL;
+		vala_vapi_gen_library = (_tmp24 = (_tmp23 = vala_gir_parser_get_package_name (girparser), (_tmp23 == NULL) ? NULL : g_strdup (_tmp23)), vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL), _tmp24);
+	}
 	if (vala_vapi_gen_library != NULL) {
 		ValaCodeWriter* interface_writer;
-		char* _tmp24;
-		char* _tmp25;
+		char* _tmp27;
+		char* _tmp28;
 		/* interface writer ignores external packages*/
 		{
-			GeeList* _tmp22;
-			GeeIterator* _tmp23;
+			GeeList* _tmp25;
+			GeeIterator* _tmp26;
 			GeeIterator* _file_it;
 			/* interface writer ignores external packages*/
-			_tmp22 = NULL;
-			_tmp23 = NULL;
-			_file_it = (_tmp23 = gee_iterable_iterator ((GeeIterable*) (_tmp22 = vala_code_context_get_source_files (self->priv->context))), (_tmp22 == NULL) ? NULL : (_tmp22 = (gee_collection_object_unref (_tmp22), NULL)), _tmp23);
+			_tmp25 = NULL;
+			_tmp26 = NULL;
+			_file_it = (_tmp26 = gee_iterable_iterator ((GeeIterable*) (_tmp25 = vala_code_context_get_source_files (self->priv->context))), (_tmp25 == NULL) ? NULL : (_tmp25 = (gee_collection_object_unref (_tmp25), NULL)), _tmp26);
 			/* interface writer ignores external packages*/
 			while (gee_iterator_next (_file_it)) {
 				ValaSourceFile* file;
@@ -388,14 +402,14 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 			(_file_it == NULL) ? NULL : (_file_it = (gee_collection_object_unref (_file_it), NULL));
 		}
 		interface_writer = vala_code_writer_new (FALSE);
-		_tmp24 = NULL;
-		vala_code_writer_write_file (interface_writer, self->priv->context, _tmp24 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library));
-		_tmp24 = (g_free (_tmp24), NULL);
-		_tmp25 = NULL;
-		vala_vapi_gen_library = (_tmp25 = NULL, vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL), _tmp25);
+		_tmp27 = NULL;
+		vala_code_writer_write_file (interface_writer, self->priv->context, _tmp27 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library));
+		_tmp27 = (g_free (_tmp27), NULL);
+		_tmp28 = NULL;
+		vala_vapi_gen_library = (_tmp28 = NULL, vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL), _tmp28);
 		(interface_writer == NULL) ? NULL : (interface_writer = (vala_code_visitor_unref (interface_writer), NULL));
 	}
-	return (_tmp26 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), (analyzer == NULL) ? NULL : (analyzer = (vala_code_visitor_unref (analyzer), NULL)), _tmp26);
+	return (_tmp29 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), (analyzer == NULL) ? NULL : (analyzer = (vala_code_visitor_unref (analyzer), NULL)), _tmp29);
 }
 
 
